"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import shared.shared_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class DataCatalogEntryXGcsFilesetSpec(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class SampleGcsFileSpecsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    FILE_PATTERNS_FIELD_NUMBER: builtins.int
    SAMPLE_GCS_FILE_SPECS_FIELD_NUMBER: builtins.int
    @property
    def file_patterns(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def sample_gcs_file_specs(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    def __init__(
        self,
        *,
        file_patterns: collections.abc.Iterable[builtins.str] | None = ...,
        sample_gcs_file_specs: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["file_patterns", b"file_patterns", "sample_gcs_file_specs", b"sample_gcs_file_specs"]) -> None: ...

global___DataCatalogEntryXGcsFilesetSpec = DataCatalogEntryXGcsFilesetSpec

@typing_extensions.final
class DataCatalogEntryXTimeouts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_FIELD_NUMBER: builtins.int
    DELETE_FIELD_NUMBER: builtins.int
    UPDATE_FIELD_NUMBER: builtins.int
    create: builtins.str
    delete: builtins.str
    update: builtins.str
    def __init__(
        self,
        *,
        create: builtins.str = ...,
        delete: builtins.str = ...,
        update: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["create", b"create", "delete", b"delete", "update", b"update"]) -> None: ...

global___DataCatalogEntryXTimeouts = DataCatalogEntryXTimeouts

@typing_extensions.final
class DataCatalogEntry(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class BigqueryDateShardedSpecEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    @typing_extensions.final
    class BigqueryTableSpecEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    BIGQUERY_DATE_SHARDED_SPEC_FIELD_NUMBER: builtins.int
    BIGQUERY_TABLE_SPEC_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    DISPLAY_NAME_FIELD_NUMBER: builtins.int
    ENTRY_GROUP_FIELD_NUMBER: builtins.int
    ENTRY_ID_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    INTEGRATED_SYSTEM_FIELD_NUMBER: builtins.int
    LINKED_RESOURCE_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    SCHEMA_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    USER_SPECIFIED_SYSTEM_FIELD_NUMBER: builtins.int
    USER_SPECIFIED_TYPE_FIELD_NUMBER: builtins.int
    GCS_FILESET_SPEC_FIELD_NUMBER: builtins.int
    TIMEOUTS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    @property
    def bigquery_date_sharded_spec(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    @property
    def bigquery_table_spec(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    description: builtins.str
    display_name: builtins.str
    entry_group: builtins.str
    entry_id: builtins.str
    id: builtins.str
    integrated_system: builtins.str
    linked_resource: builtins.str
    name: builtins.str
    schema: builtins.str
    type: builtins.str
    user_specified_system: builtins.str
    user_specified_type: builtins.str
    @property
    def gcs_fileset_spec(self) -> global___DataCatalogEntryXGcsFilesetSpec: ...
    @property
    def timeouts(self) -> global___DataCatalogEntryXTimeouts: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        bigquery_date_sharded_spec: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        bigquery_table_spec: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        description: builtins.str = ...,
        display_name: builtins.str = ...,
        entry_group: builtins.str = ...,
        entry_id: builtins.str = ...,
        id: builtins.str = ...,
        integrated_system: builtins.str = ...,
        linked_resource: builtins.str = ...,
        name: builtins.str = ...,
        schema: builtins.str = ...,
        type: builtins.str = ...,
        user_specified_system: builtins.str = ...,
        user_specified_type: builtins.str = ...,
        gcs_fileset_spec: global___DataCatalogEntryXGcsFilesetSpec | None = ...,
        timeouts: global___DataCatalogEntryXTimeouts | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["gcs_fileset_spec", b"gcs_fileset_spec", "resource_info", b"resource_info", "timeouts", b"timeouts"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["bigquery_date_sharded_spec", b"bigquery_date_sharded_spec", "bigquery_table_spec", b"bigquery_table_spec", "description", b"description", "display_name", b"display_name", "entry_group", b"entry_group", "entry_id", b"entry_id", "gcs_fileset_spec", b"gcs_fileset_spec", "id", b"id", "integrated_system", b"integrated_system", "linked_resource", b"linked_resource", "name", b"name", "resource_info", b"resource_info", "schema", b"schema", "timeouts", b"timeouts", "type", b"type", "user_specified_system", b"user_specified_system", "user_specified_type", b"user_specified_type"]) -> None: ...

global___DataCatalogEntry = DataCatalogEntry

@typing_extensions.final
class DataCatalogEntryGroupXTimeouts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_FIELD_NUMBER: builtins.int
    DELETE_FIELD_NUMBER: builtins.int
    UPDATE_FIELD_NUMBER: builtins.int
    create: builtins.str
    delete: builtins.str
    update: builtins.str
    def __init__(
        self,
        *,
        create: builtins.str = ...,
        delete: builtins.str = ...,
        update: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["create", b"create", "delete", b"delete", "update", b"update"]) -> None: ...

global___DataCatalogEntryGroupXTimeouts = DataCatalogEntryGroupXTimeouts

@typing_extensions.final
class DataCatalogEntryGroup(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DESCRIPTION_FIELD_NUMBER: builtins.int
    DISPLAY_NAME_FIELD_NUMBER: builtins.int
    ENTRY_GROUP_ID_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    REGION_FIELD_NUMBER: builtins.int
    TIMEOUTS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    description: builtins.str
    display_name: builtins.str
    entry_group_id: builtins.str
    id: builtins.str
    name: builtins.str
    project: builtins.str
    region: builtins.str
    @property
    def timeouts(self) -> global___DataCatalogEntryGroupXTimeouts: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        description: builtins.str = ...,
        display_name: builtins.str = ...,
        entry_group_id: builtins.str = ...,
        id: builtins.str = ...,
        name: builtins.str = ...,
        project: builtins.str = ...,
        region: builtins.str = ...,
        timeouts: global___DataCatalogEntryGroupXTimeouts | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "timeouts", b"timeouts"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["description", b"description", "display_name", b"display_name", "entry_group_id", b"entry_group_id", "id", b"id", "name", b"name", "project", b"project", "region", b"region", "resource_info", b"resource_info", "timeouts", b"timeouts"]) -> None: ...

global___DataCatalogEntryGroup = DataCatalogEntryGroup

@typing_extensions.final
class DataCatalogEntryGroupIamBindingXCondition(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DESCRIPTION_FIELD_NUMBER: builtins.int
    EXPRESSION_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    description: builtins.str
    expression: builtins.str
    title: builtins.str
    def __init__(
        self,
        *,
        description: builtins.str = ...,
        expression: builtins.str = ...,
        title: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["description", b"description", "expression", b"expression", "title", b"title"]) -> None: ...

global___DataCatalogEntryGroupIamBindingXCondition = DataCatalogEntryGroupIamBindingXCondition

@typing_extensions.final
class DataCatalogEntryGroupIamBinding(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENTRY_GROUP_FIELD_NUMBER: builtins.int
    ETAG_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    MEMBERS_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    REGION_FIELD_NUMBER: builtins.int
    ROLE_FIELD_NUMBER: builtins.int
    CONDITION_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    entry_group: builtins.str
    etag: builtins.str
    id: builtins.str
    @property
    def members(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    project: builtins.str
    region: builtins.str
    role: builtins.str
    @property
    def condition(self) -> global___DataCatalogEntryGroupIamBindingXCondition: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        entry_group: builtins.str = ...,
        etag: builtins.str = ...,
        id: builtins.str = ...,
        members: collections.abc.Iterable[builtins.str] | None = ...,
        project: builtins.str = ...,
        region: builtins.str = ...,
        role: builtins.str = ...,
        condition: global___DataCatalogEntryGroupIamBindingXCondition | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["condition", b"condition", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["condition", b"condition", "entry_group", b"entry_group", "etag", b"etag", "id", b"id", "members", b"members", "project", b"project", "region", b"region", "resource_info", b"resource_info", "role", b"role"]) -> None: ...

global___DataCatalogEntryGroupIamBinding = DataCatalogEntryGroupIamBinding

@typing_extensions.final
class DataCatalogEntryGroupIamMemberXCondition(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DESCRIPTION_FIELD_NUMBER: builtins.int
    EXPRESSION_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    description: builtins.str
    expression: builtins.str
    title: builtins.str
    def __init__(
        self,
        *,
        description: builtins.str = ...,
        expression: builtins.str = ...,
        title: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["description", b"description", "expression", b"expression", "title", b"title"]) -> None: ...

global___DataCatalogEntryGroupIamMemberXCondition = DataCatalogEntryGroupIamMemberXCondition

@typing_extensions.final
class DataCatalogEntryGroupIamMember(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENTRY_GROUP_FIELD_NUMBER: builtins.int
    ETAG_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    MEMBER_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    REGION_FIELD_NUMBER: builtins.int
    ROLE_FIELD_NUMBER: builtins.int
    CONDITION_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    entry_group: builtins.str
    etag: builtins.str
    id: builtins.str
    member: builtins.str
    project: builtins.str
    region: builtins.str
    role: builtins.str
    @property
    def condition(self) -> global___DataCatalogEntryGroupIamMemberXCondition: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        entry_group: builtins.str = ...,
        etag: builtins.str = ...,
        id: builtins.str = ...,
        member: builtins.str = ...,
        project: builtins.str = ...,
        region: builtins.str = ...,
        role: builtins.str = ...,
        condition: global___DataCatalogEntryGroupIamMemberXCondition | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["condition", b"condition", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["condition", b"condition", "entry_group", b"entry_group", "etag", b"etag", "id", b"id", "member", b"member", "project", b"project", "region", b"region", "resource_info", b"resource_info", "role", b"role"]) -> None: ...

global___DataCatalogEntryGroupIamMember = DataCatalogEntryGroupIamMember

@typing_extensions.final
class DataCatalogEntryGroupIamPolicy(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENTRY_GROUP_FIELD_NUMBER: builtins.int
    ETAG_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    POLICY_DATA_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    REGION_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    entry_group: builtins.str
    etag: builtins.str
    id: builtins.str
    policy_data: builtins.str
    project: builtins.str
    region: builtins.str
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        entry_group: builtins.str = ...,
        etag: builtins.str = ...,
        id: builtins.str = ...,
        policy_data: builtins.str = ...,
        project: builtins.str = ...,
        region: builtins.str = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["entry_group", b"entry_group", "etag", b"etag", "id", b"id", "policy_data", b"policy_data", "project", b"project", "region", b"region", "resource_info", b"resource_info"]) -> None: ...

global___DataCatalogEntryGroupIamPolicy = DataCatalogEntryGroupIamPolicy

@typing_extensions.final
class DataCatalogTagXFields(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BOOL_VALUE_FIELD_NUMBER: builtins.int
    DISPLAY_NAME_FIELD_NUMBER: builtins.int
    DOUBLE_VALUE_FIELD_NUMBER: builtins.int
    ENUM_VALUE_FIELD_NUMBER: builtins.int
    FIELD_NAME_FIELD_NUMBER: builtins.int
    ORDER_FIELD_NUMBER: builtins.int
    STRING_VALUE_FIELD_NUMBER: builtins.int
    TIMESTAMP_VALUE_FIELD_NUMBER: builtins.int
    bool_value: builtins.bool
    display_name: builtins.str
    double_value: builtins.float
    enum_value: builtins.str
    field_name: builtins.str
    order: builtins.float
    string_value: builtins.str
    timestamp_value: builtins.str
    def __init__(
        self,
        *,
        bool_value: builtins.bool = ...,
        display_name: builtins.str = ...,
        double_value: builtins.float = ...,
        enum_value: builtins.str = ...,
        field_name: builtins.str = ...,
        order: builtins.float = ...,
        string_value: builtins.str = ...,
        timestamp_value: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["bool_value", b"bool_value", "display_name", b"display_name", "double_value", b"double_value", "enum_value", b"enum_value", "field_name", b"field_name", "order", b"order", "string_value", b"string_value", "timestamp_value", b"timestamp_value"]) -> None: ...

global___DataCatalogTagXFields = DataCatalogTagXFields

@typing_extensions.final
class DataCatalogTagXTimeouts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_FIELD_NUMBER: builtins.int
    DELETE_FIELD_NUMBER: builtins.int
    UPDATE_FIELD_NUMBER: builtins.int
    create: builtins.str
    delete: builtins.str
    update: builtins.str
    def __init__(
        self,
        *,
        create: builtins.str = ...,
        delete: builtins.str = ...,
        update: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["create", b"create", "delete", b"delete", "update", b"update"]) -> None: ...

global___DataCatalogTagXTimeouts = DataCatalogTagXTimeouts

@typing_extensions.final
class DataCatalogTag(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    COLUMN_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    PARENT_FIELD_NUMBER: builtins.int
    TEMPLATE_FIELD_NUMBER: builtins.int
    TEMPLATE_DISPLAYNAME_FIELD_NUMBER: builtins.int
    FIELDS_FIELD_NUMBER: builtins.int
    TIMEOUTS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    column: builtins.str
    id: builtins.str
    name: builtins.str
    parent: builtins.str
    template: builtins.str
    template_displayname: builtins.str
    @property
    def fields(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DataCatalogTagXFields]: ...
    @property
    def timeouts(self) -> global___DataCatalogTagXTimeouts: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        column: builtins.str = ...,
        id: builtins.str = ...,
        name: builtins.str = ...,
        parent: builtins.str = ...,
        template: builtins.str = ...,
        template_displayname: builtins.str = ...,
        fields: collections.abc.Iterable[global___DataCatalogTagXFields] | None = ...,
        timeouts: global___DataCatalogTagXTimeouts | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "timeouts", b"timeouts"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["column", b"column", "fields", b"fields", "id", b"id", "name", b"name", "parent", b"parent", "resource_info", b"resource_info", "template", b"template", "template_displayname", b"template_displayname", "timeouts", b"timeouts"]) -> None: ...

global___DataCatalogTag = DataCatalogTag

@typing_extensions.final
class DataCatalogTagTemplateXFieldsXTypeXEnumTypeXAllowedValues(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DISPLAY_NAME_FIELD_NUMBER: builtins.int
    display_name: builtins.str
    def __init__(
        self,
        *,
        display_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["display_name", b"display_name"]) -> None: ...

global___DataCatalogTagTemplateXFieldsXTypeXEnumTypeXAllowedValues = DataCatalogTagTemplateXFieldsXTypeXEnumTypeXAllowedValues

@typing_extensions.final
class DataCatalogTagTemplateXFieldsXTypeXEnumType(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ALLOWED_VALUES_FIELD_NUMBER: builtins.int
    @property
    def allowed_values(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DataCatalogTagTemplateXFieldsXTypeXEnumTypeXAllowedValues]: ...
    def __init__(
        self,
        *,
        allowed_values: collections.abc.Iterable[global___DataCatalogTagTemplateXFieldsXTypeXEnumTypeXAllowedValues] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["allowed_values", b"allowed_values"]) -> None: ...

global___DataCatalogTagTemplateXFieldsXTypeXEnumType = DataCatalogTagTemplateXFieldsXTypeXEnumType

@typing_extensions.final
class DataCatalogTagTemplateXFieldsXType(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PRIMITIVE_TYPE_FIELD_NUMBER: builtins.int
    ENUM_TYPE_FIELD_NUMBER: builtins.int
    primitive_type: builtins.str
    @property
    def enum_type(self) -> global___DataCatalogTagTemplateXFieldsXTypeXEnumType: ...
    def __init__(
        self,
        *,
        primitive_type: builtins.str = ...,
        enum_type: global___DataCatalogTagTemplateXFieldsXTypeXEnumType | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["enum_type", b"enum_type"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["enum_type", b"enum_type", "primitive_type", b"primitive_type"]) -> None: ...

global___DataCatalogTagTemplateXFieldsXType = DataCatalogTagTemplateXFieldsXType

@typing_extensions.final
class DataCatalogTagTemplateXFields(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DESCRIPTION_FIELD_NUMBER: builtins.int
    DISPLAY_NAME_FIELD_NUMBER: builtins.int
    FIELD_ID_FIELD_NUMBER: builtins.int
    IS_REQUIRED_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    ORDER_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    description: builtins.str
    display_name: builtins.str
    field_id: builtins.str
    is_required: builtins.bool
    name: builtins.str
    order: builtins.float
    @property
    def type(self) -> global___DataCatalogTagTemplateXFieldsXType: ...
    def __init__(
        self,
        *,
        description: builtins.str = ...,
        display_name: builtins.str = ...,
        field_id: builtins.str = ...,
        is_required: builtins.bool = ...,
        name: builtins.str = ...,
        order: builtins.float = ...,
        type: global___DataCatalogTagTemplateXFieldsXType | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["type", b"type"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["description", b"description", "display_name", b"display_name", "field_id", b"field_id", "is_required", b"is_required", "name", b"name", "order", b"order", "type", b"type"]) -> None: ...

global___DataCatalogTagTemplateXFields = DataCatalogTagTemplateXFields

@typing_extensions.final
class DataCatalogTagTemplateXTimeouts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_FIELD_NUMBER: builtins.int
    DELETE_FIELD_NUMBER: builtins.int
    UPDATE_FIELD_NUMBER: builtins.int
    create: builtins.str
    delete: builtins.str
    update: builtins.str
    def __init__(
        self,
        *,
        create: builtins.str = ...,
        delete: builtins.str = ...,
        update: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["create", b"create", "delete", b"delete", "update", b"update"]) -> None: ...

global___DataCatalogTagTemplateXTimeouts = DataCatalogTagTemplateXTimeouts

@typing_extensions.final
class DataCatalogTagTemplate(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DISPLAY_NAME_FIELD_NUMBER: builtins.int
    FORCE_DELETE_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    REGION_FIELD_NUMBER: builtins.int
    TAG_TEMPLATE_ID_FIELD_NUMBER: builtins.int
    FIELDS_FIELD_NUMBER: builtins.int
    TIMEOUTS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    display_name: builtins.str
    force_delete: builtins.bool
    id: builtins.str
    name: builtins.str
    project: builtins.str
    region: builtins.str
    tag_template_id: builtins.str
    @property
    def fields(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DataCatalogTagTemplateXFields]: ...
    @property
    def timeouts(self) -> global___DataCatalogTagTemplateXTimeouts: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        display_name: builtins.str = ...,
        force_delete: builtins.bool = ...,
        id: builtins.str = ...,
        name: builtins.str = ...,
        project: builtins.str = ...,
        region: builtins.str = ...,
        tag_template_id: builtins.str = ...,
        fields: collections.abc.Iterable[global___DataCatalogTagTemplateXFields] | None = ...,
        timeouts: global___DataCatalogTagTemplateXTimeouts | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "timeouts", b"timeouts"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["display_name", b"display_name", "fields", b"fields", "force_delete", b"force_delete", "id", b"id", "name", b"name", "project", b"project", "region", b"region", "resource_info", b"resource_info", "tag_template_id", b"tag_template_id", "timeouts", b"timeouts"]) -> None: ...

global___DataCatalogTagTemplate = DataCatalogTagTemplate

@typing_extensions.final
class DataCatalogTagTemplateIamBindingXCondition(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DESCRIPTION_FIELD_NUMBER: builtins.int
    EXPRESSION_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    description: builtins.str
    expression: builtins.str
    title: builtins.str
    def __init__(
        self,
        *,
        description: builtins.str = ...,
        expression: builtins.str = ...,
        title: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["description", b"description", "expression", b"expression", "title", b"title"]) -> None: ...

global___DataCatalogTagTemplateIamBindingXCondition = DataCatalogTagTemplateIamBindingXCondition

@typing_extensions.final
class DataCatalogTagTemplateIamBinding(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ETAG_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    MEMBERS_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    REGION_FIELD_NUMBER: builtins.int
    ROLE_FIELD_NUMBER: builtins.int
    TAG_TEMPLATE_FIELD_NUMBER: builtins.int
    CONDITION_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    etag: builtins.str
    id: builtins.str
    @property
    def members(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    project: builtins.str
    region: builtins.str
    role: builtins.str
    tag_template: builtins.str
    @property
    def condition(self) -> global___DataCatalogTagTemplateIamBindingXCondition: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        etag: builtins.str = ...,
        id: builtins.str = ...,
        members: collections.abc.Iterable[builtins.str] | None = ...,
        project: builtins.str = ...,
        region: builtins.str = ...,
        role: builtins.str = ...,
        tag_template: builtins.str = ...,
        condition: global___DataCatalogTagTemplateIamBindingXCondition | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["condition", b"condition", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["condition", b"condition", "etag", b"etag", "id", b"id", "members", b"members", "project", b"project", "region", b"region", "resource_info", b"resource_info", "role", b"role", "tag_template", b"tag_template"]) -> None: ...

global___DataCatalogTagTemplateIamBinding = DataCatalogTagTemplateIamBinding

@typing_extensions.final
class DataCatalogTagTemplateIamMemberXCondition(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DESCRIPTION_FIELD_NUMBER: builtins.int
    EXPRESSION_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    description: builtins.str
    expression: builtins.str
    title: builtins.str
    def __init__(
        self,
        *,
        description: builtins.str = ...,
        expression: builtins.str = ...,
        title: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["description", b"description", "expression", b"expression", "title", b"title"]) -> None: ...

global___DataCatalogTagTemplateIamMemberXCondition = DataCatalogTagTemplateIamMemberXCondition

@typing_extensions.final
class DataCatalogTagTemplateIamMember(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ETAG_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    MEMBER_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    REGION_FIELD_NUMBER: builtins.int
    ROLE_FIELD_NUMBER: builtins.int
    TAG_TEMPLATE_FIELD_NUMBER: builtins.int
    CONDITION_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    etag: builtins.str
    id: builtins.str
    member: builtins.str
    project: builtins.str
    region: builtins.str
    role: builtins.str
    tag_template: builtins.str
    @property
    def condition(self) -> global___DataCatalogTagTemplateIamMemberXCondition: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        etag: builtins.str = ...,
        id: builtins.str = ...,
        member: builtins.str = ...,
        project: builtins.str = ...,
        region: builtins.str = ...,
        role: builtins.str = ...,
        tag_template: builtins.str = ...,
        condition: global___DataCatalogTagTemplateIamMemberXCondition | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["condition", b"condition", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["condition", b"condition", "etag", b"etag", "id", b"id", "member", b"member", "project", b"project", "region", b"region", "resource_info", b"resource_info", "role", b"role", "tag_template", b"tag_template"]) -> None: ...

global___DataCatalogTagTemplateIamMember = DataCatalogTagTemplateIamMember

@typing_extensions.final
class DataCatalogTagTemplateIamPolicy(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ETAG_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    POLICY_DATA_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    REGION_FIELD_NUMBER: builtins.int
    TAG_TEMPLATE_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    etag: builtins.str
    id: builtins.str
    policy_data: builtins.str
    project: builtins.str
    region: builtins.str
    tag_template: builtins.str
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        etag: builtins.str = ...,
        id: builtins.str = ...,
        policy_data: builtins.str = ...,
        project: builtins.str = ...,
        region: builtins.str = ...,
        tag_template: builtins.str = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["etag", b"etag", "id", b"id", "policy_data", b"policy_data", "project", b"project", "region", b"region", "resource_info", b"resource_info", "tag_template", b"tag_template"]) -> None: ...

global___DataCatalogTagTemplateIamPolicy = DataCatalogTagTemplateIamPolicy

@typing_extensions.final
class DataFusionInstanceXNetworkConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    IP_ALLOCATION_FIELD_NUMBER: builtins.int
    NETWORK_FIELD_NUMBER: builtins.int
    ip_allocation: builtins.str
    network: builtins.str
    def __init__(
        self,
        *,
        ip_allocation: builtins.str = ...,
        network: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["ip_allocation", b"ip_allocation", "network", b"network"]) -> None: ...

global___DataFusionInstanceXNetworkConfig = DataFusionInstanceXNetworkConfig

@typing_extensions.final
class DataFusionInstanceXTimeouts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_FIELD_NUMBER: builtins.int
    DELETE_FIELD_NUMBER: builtins.int
    UPDATE_FIELD_NUMBER: builtins.int
    create: builtins.str
    delete: builtins.str
    update: builtins.str
    def __init__(
        self,
        *,
        create: builtins.str = ...,
        delete: builtins.str = ...,
        update: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["create", b"create", "delete", b"delete", "update", b"update"]) -> None: ...

global___DataFusionInstanceXTimeouts = DataFusionInstanceXTimeouts

@typing_extensions.final
class DataFusionInstance(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    @typing_extensions.final
    class OptionsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    CREATE_TIME_FIELD_NUMBER: builtins.int
    DATAPROC_SERVICE_ACCOUNT_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    ENABLE_STACKDRIVER_LOGGING_FIELD_NUMBER: builtins.int
    ENABLE_STACKDRIVER_MONITORING_FIELD_NUMBER: builtins.int
    GCS_BUCKET_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    OPTIONS_FIELD_NUMBER: builtins.int
    PRIVATE_INSTANCE_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    REGION_FIELD_NUMBER: builtins.int
    SERVICE_ENDPOINT_FIELD_NUMBER: builtins.int
    STATE_FIELD_NUMBER: builtins.int
    STATE_MESSAGE_FIELD_NUMBER: builtins.int
    TENANT_PROJECT_ID_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    UPDATE_TIME_FIELD_NUMBER: builtins.int
    VERSION_FIELD_NUMBER: builtins.int
    NETWORK_CONFIG_FIELD_NUMBER: builtins.int
    TIMEOUTS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    create_time: builtins.str
    dataproc_service_account: builtins.str
    description: builtins.str
    enable_stackdriver_logging: builtins.bool
    enable_stackdriver_monitoring: builtins.bool
    gcs_bucket: builtins.str
    id: builtins.str
    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    name: builtins.str
    @property
    def options(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    private_instance: builtins.bool
    project: builtins.str
    region: builtins.str
    service_endpoint: builtins.str
    state: builtins.str
    state_message: builtins.str
    tenant_project_id: builtins.str
    type: builtins.str
    update_time: builtins.str
    version: builtins.str
    @property
    def network_config(self) -> global___DataFusionInstanceXNetworkConfig: ...
    @property
    def timeouts(self) -> global___DataFusionInstanceXTimeouts: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        create_time: builtins.str = ...,
        dataproc_service_account: builtins.str = ...,
        description: builtins.str = ...,
        enable_stackdriver_logging: builtins.bool = ...,
        enable_stackdriver_monitoring: builtins.bool = ...,
        gcs_bucket: builtins.str = ...,
        id: builtins.str = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        name: builtins.str = ...,
        options: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        private_instance: builtins.bool = ...,
        project: builtins.str = ...,
        region: builtins.str = ...,
        service_endpoint: builtins.str = ...,
        state: builtins.str = ...,
        state_message: builtins.str = ...,
        tenant_project_id: builtins.str = ...,
        type: builtins.str = ...,
        update_time: builtins.str = ...,
        version: builtins.str = ...,
        network_config: global___DataFusionInstanceXNetworkConfig | None = ...,
        timeouts: global___DataFusionInstanceXTimeouts | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["network_config", b"network_config", "resource_info", b"resource_info", "timeouts", b"timeouts"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["create_time", b"create_time", "dataproc_service_account", b"dataproc_service_account", "description", b"description", "enable_stackdriver_logging", b"enable_stackdriver_logging", "enable_stackdriver_monitoring", b"enable_stackdriver_monitoring", "gcs_bucket", b"gcs_bucket", "id", b"id", "labels", b"labels", "name", b"name", "network_config", b"network_config", "options", b"options", "private_instance", b"private_instance", "project", b"project", "region", b"region", "resource_info", b"resource_info", "service_endpoint", b"service_endpoint", "state", b"state", "state_message", b"state_message", "tenant_project_id", b"tenant_project_id", "timeouts", b"timeouts", "type", b"type", "update_time", b"update_time", "version", b"version"]) -> None: ...

global___DataFusionInstance = DataFusionInstance

@typing_extensions.final
class DataLossPreventionDeidentifyTemplateXDeidentifyConfigXInfoTypeTransformationsXTransformationsXInfoTypes(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    name: builtins.str
    def __init__(
        self,
        *,
        name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name"]) -> None: ...

global___DataLossPreventionDeidentifyTemplateXDeidentifyConfigXInfoTypeTransformationsXTransformationsXInfoTypes = DataLossPreventionDeidentifyTemplateXDeidentifyConfigXInfoTypeTransformationsXTransformationsXInfoTypes

@typing_extensions.final
class DataLossPreventionDeidentifyTemplateXDeidentifyConfigXInfoTypeTransformationsXTransformationsXPrimitiveTransformationXCharacterMaskConfigXCharactersToIgnore(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CHARACTERS_TO_SKIP_FIELD_NUMBER: builtins.int
    COMMON_CHARACTERS_TO_IGNORE_FIELD_NUMBER: builtins.int
    characters_to_skip: builtins.str
    common_characters_to_ignore: builtins.str
    def __init__(
        self,
        *,
        characters_to_skip: builtins.str = ...,
        common_characters_to_ignore: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["characters_to_skip", b"characters_to_skip", "common_characters_to_ignore", b"common_characters_to_ignore"]) -> None: ...

global___DataLossPreventionDeidentifyTemplateXDeidentifyConfigXInfoTypeTransformationsXTransformationsXPrimitiveTransformationXCharacterMaskConfigXCharactersToIgnore = DataLossPreventionDeidentifyTemplateXDeidentifyConfigXInfoTypeTransformationsXTransformationsXPrimitiveTransformationXCharacterMaskConfigXCharactersToIgnore

@typing_extensions.final
class DataLossPreventionDeidentifyTemplateXDeidentifyConfigXInfoTypeTransformationsXTransformationsXPrimitiveTransformationXCharacterMaskConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MASKING_CHARACTER_FIELD_NUMBER: builtins.int
    NUMBER_TO_MASK_FIELD_NUMBER: builtins.int
    REVERSE_ORDER_FIELD_NUMBER: builtins.int
    CHARACTERS_TO_IGNORE_FIELD_NUMBER: builtins.int
    masking_character: builtins.str
    number_to_mask: builtins.float
    reverse_order: builtins.bool
    @property
    def characters_to_ignore(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DataLossPreventionDeidentifyTemplateXDeidentifyConfigXInfoTypeTransformationsXTransformationsXPrimitiveTransformationXCharacterMaskConfigXCharactersToIgnore]: ...
    def __init__(
        self,
        *,
        masking_character: builtins.str = ...,
        number_to_mask: builtins.float = ...,
        reverse_order: builtins.bool = ...,
        characters_to_ignore: collections.abc.Iterable[global___DataLossPreventionDeidentifyTemplateXDeidentifyConfigXInfoTypeTransformationsXTransformationsXPrimitiveTransformationXCharacterMaskConfigXCharactersToIgnore] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["characters_to_ignore", b"characters_to_ignore", "masking_character", b"masking_character", "number_to_mask", b"number_to_mask", "reverse_order", b"reverse_order"]) -> None: ...

global___DataLossPreventionDeidentifyTemplateXDeidentifyConfigXInfoTypeTransformationsXTransformationsXPrimitiveTransformationXCharacterMaskConfig = DataLossPreventionDeidentifyTemplateXDeidentifyConfigXInfoTypeTransformationsXTransformationsXPrimitiveTransformationXCharacterMaskConfig

@typing_extensions.final
class DataLossPreventionDeidentifyTemplateXDeidentifyConfigXInfoTypeTransformationsXTransformationsXPrimitiveTransformationXCryptoDeterministicConfigXContext(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    name: builtins.str
    def __init__(
        self,
        *,
        name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name"]) -> None: ...

global___DataLossPreventionDeidentifyTemplateXDeidentifyConfigXInfoTypeTransformationsXTransformationsXPrimitiveTransformationXCryptoDeterministicConfigXContext = DataLossPreventionDeidentifyTemplateXDeidentifyConfigXInfoTypeTransformationsXTransformationsXPrimitiveTransformationXCryptoDeterministicConfigXContext

@typing_extensions.final
class DataLossPreventionDeidentifyTemplateXDeidentifyConfigXInfoTypeTransformationsXTransformationsXPrimitiveTransformationXCryptoDeterministicConfigXCryptoKeyXKmsWrapped(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CRYPTO_KEY_NAME_FIELD_NUMBER: builtins.int
    WRAPPED_KEY_FIELD_NUMBER: builtins.int
    crypto_key_name: builtins.str
    wrapped_key: builtins.str
    def __init__(
        self,
        *,
        crypto_key_name: builtins.str = ...,
        wrapped_key: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["crypto_key_name", b"crypto_key_name", "wrapped_key", b"wrapped_key"]) -> None: ...

global___DataLossPreventionDeidentifyTemplateXDeidentifyConfigXInfoTypeTransformationsXTransformationsXPrimitiveTransformationXCryptoDeterministicConfigXCryptoKeyXKmsWrapped = DataLossPreventionDeidentifyTemplateXDeidentifyConfigXInfoTypeTransformationsXTransformationsXPrimitiveTransformationXCryptoDeterministicConfigXCryptoKeyXKmsWrapped

@typing_extensions.final
class DataLossPreventionDeidentifyTemplateXDeidentifyConfigXInfoTypeTransformationsXTransformationsXPrimitiveTransformationXCryptoDeterministicConfigXCryptoKeyXTransient(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    name: builtins.str
    def __init__(
        self,
        *,
        name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name"]) -> None: ...

global___DataLossPreventionDeidentifyTemplateXDeidentifyConfigXInfoTypeTransformationsXTransformationsXPrimitiveTransformationXCryptoDeterministicConfigXCryptoKeyXTransient = DataLossPreventionDeidentifyTemplateXDeidentifyConfigXInfoTypeTransformationsXTransformationsXPrimitiveTransformationXCryptoDeterministicConfigXCryptoKeyXTransient

@typing_extensions.final
class DataLossPreventionDeidentifyTemplateXDeidentifyConfigXInfoTypeTransformationsXTransformationsXPrimitiveTransformationXCryptoDeterministicConfigXCryptoKeyXUnwrapped(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    KEY_FIELD_NUMBER: builtins.int
    key: builtins.str
    def __init__(
        self,
        *,
        key: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["key", b"key"]) -> None: ...

global___DataLossPreventionDeidentifyTemplateXDeidentifyConfigXInfoTypeTransformationsXTransformationsXPrimitiveTransformationXCryptoDeterministicConfigXCryptoKeyXUnwrapped = DataLossPreventionDeidentifyTemplateXDeidentifyConfigXInfoTypeTransformationsXTransformationsXPrimitiveTransformationXCryptoDeterministicConfigXCryptoKeyXUnwrapped

@typing_extensions.final
class DataLossPreventionDeidentifyTemplateXDeidentifyConfigXInfoTypeTransformationsXTransformationsXPrimitiveTransformationXCryptoDeterministicConfigXCryptoKey(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    KMS_WRAPPED_FIELD_NUMBER: builtins.int
    TRANSIENT_FIELD_NUMBER: builtins.int
    UNWRAPPED_FIELD_NUMBER: builtins.int
    @property
    def kms_wrapped(self) -> global___DataLossPreventionDeidentifyTemplateXDeidentifyConfigXInfoTypeTransformationsXTransformationsXPrimitiveTransformationXCryptoDeterministicConfigXCryptoKeyXKmsWrapped: ...
    @property
    def transient(self) -> global___DataLossPreventionDeidentifyTemplateXDeidentifyConfigXInfoTypeTransformationsXTransformationsXPrimitiveTransformationXCryptoDeterministicConfigXCryptoKeyXTransient: ...
    @property
    def unwrapped(self) -> global___DataLossPreventionDeidentifyTemplateXDeidentifyConfigXInfoTypeTransformationsXTransformationsXPrimitiveTransformationXCryptoDeterministicConfigXCryptoKeyXUnwrapped: ...
    def __init__(
        self,
        *,
        kms_wrapped: global___DataLossPreventionDeidentifyTemplateXDeidentifyConfigXInfoTypeTransformationsXTransformationsXPrimitiveTransformationXCryptoDeterministicConfigXCryptoKeyXKmsWrapped | None = ...,
        transient: global___DataLossPreventionDeidentifyTemplateXDeidentifyConfigXInfoTypeTransformationsXTransformationsXPrimitiveTransformationXCryptoDeterministicConfigXCryptoKeyXTransient | None = ...,
        unwrapped: global___DataLossPreventionDeidentifyTemplateXDeidentifyConfigXInfoTypeTransformationsXTransformationsXPrimitiveTransformationXCryptoDeterministicConfigXCryptoKeyXUnwrapped | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["kms_wrapped", b"kms_wrapped", "transient", b"transient", "unwrapped", b"unwrapped"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["kms_wrapped", b"kms_wrapped", "transient", b"transient", "unwrapped", b"unwrapped"]) -> None: ...

global___DataLossPreventionDeidentifyTemplateXDeidentifyConfigXInfoTypeTransformationsXTransformationsXPrimitiveTransformationXCryptoDeterministicConfigXCryptoKey = DataLossPreventionDeidentifyTemplateXDeidentifyConfigXInfoTypeTransformationsXTransformationsXPrimitiveTransformationXCryptoDeterministicConfigXCryptoKey

@typing_extensions.final
class DataLossPreventionDeidentifyTemplateXDeidentifyConfigXInfoTypeTransformationsXTransformationsXPrimitiveTransformationXCryptoDeterministicConfigXSurrogateInfoType(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    name: builtins.str
    def __init__(
        self,
        *,
        name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name"]) -> None: ...

global___DataLossPreventionDeidentifyTemplateXDeidentifyConfigXInfoTypeTransformationsXTransformationsXPrimitiveTransformationXCryptoDeterministicConfigXSurrogateInfoType = DataLossPreventionDeidentifyTemplateXDeidentifyConfigXInfoTypeTransformationsXTransformationsXPrimitiveTransformationXCryptoDeterministicConfigXSurrogateInfoType

@typing_extensions.final
class DataLossPreventionDeidentifyTemplateXDeidentifyConfigXInfoTypeTransformationsXTransformationsXPrimitiveTransformationXCryptoDeterministicConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CONTEXT_FIELD_NUMBER: builtins.int
    CRYPTO_KEY_FIELD_NUMBER: builtins.int
    SURROGATE_INFO_TYPE_FIELD_NUMBER: builtins.int
    @property
    def context(self) -> global___DataLossPreventionDeidentifyTemplateXDeidentifyConfigXInfoTypeTransformationsXTransformationsXPrimitiveTransformationXCryptoDeterministicConfigXContext: ...
    @property
    def crypto_key(self) -> global___DataLossPreventionDeidentifyTemplateXDeidentifyConfigXInfoTypeTransformationsXTransformationsXPrimitiveTransformationXCryptoDeterministicConfigXCryptoKey: ...
    @property
    def surrogate_info_type(self) -> global___DataLossPreventionDeidentifyTemplateXDeidentifyConfigXInfoTypeTransformationsXTransformationsXPrimitiveTransformationXCryptoDeterministicConfigXSurrogateInfoType: ...
    def __init__(
        self,
        *,
        context: global___DataLossPreventionDeidentifyTemplateXDeidentifyConfigXInfoTypeTransformationsXTransformationsXPrimitiveTransformationXCryptoDeterministicConfigXContext | None = ...,
        crypto_key: global___DataLossPreventionDeidentifyTemplateXDeidentifyConfigXInfoTypeTransformationsXTransformationsXPrimitiveTransformationXCryptoDeterministicConfigXCryptoKey | None = ...,
        surrogate_info_type: global___DataLossPreventionDeidentifyTemplateXDeidentifyConfigXInfoTypeTransformationsXTransformationsXPrimitiveTransformationXCryptoDeterministicConfigXSurrogateInfoType | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["context", b"context", "crypto_key", b"crypto_key", "surrogate_info_type", b"surrogate_info_type"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["context", b"context", "crypto_key", b"crypto_key", "surrogate_info_type", b"surrogate_info_type"]) -> None: ...

global___DataLossPreventionDeidentifyTemplateXDeidentifyConfigXInfoTypeTransformationsXTransformationsXPrimitiveTransformationXCryptoDeterministicConfig = DataLossPreventionDeidentifyTemplateXDeidentifyConfigXInfoTypeTransformationsXTransformationsXPrimitiveTransformationXCryptoDeterministicConfig

@typing_extensions.final
class DataLossPreventionDeidentifyTemplateXDeidentifyConfigXInfoTypeTransformationsXTransformationsXPrimitiveTransformationXCryptoReplaceFfxFpeConfigXContext(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    name: builtins.str
    def __init__(
        self,
        *,
        name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name"]) -> None: ...

global___DataLossPreventionDeidentifyTemplateXDeidentifyConfigXInfoTypeTransformationsXTransformationsXPrimitiveTransformationXCryptoReplaceFfxFpeConfigXContext = DataLossPreventionDeidentifyTemplateXDeidentifyConfigXInfoTypeTransformationsXTransformationsXPrimitiveTransformationXCryptoReplaceFfxFpeConfigXContext

@typing_extensions.final
class DataLossPreventionDeidentifyTemplateXDeidentifyConfigXInfoTypeTransformationsXTransformationsXPrimitiveTransformationXCryptoReplaceFfxFpeConfigXCryptoKeyXKmsWrapped(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CRYPTO_KEY_NAME_FIELD_NUMBER: builtins.int
    WRAPPED_KEY_FIELD_NUMBER: builtins.int
    crypto_key_name: builtins.str
    wrapped_key: builtins.str
    def __init__(
        self,
        *,
        crypto_key_name: builtins.str = ...,
        wrapped_key: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["crypto_key_name", b"crypto_key_name", "wrapped_key", b"wrapped_key"]) -> None: ...

global___DataLossPreventionDeidentifyTemplateXDeidentifyConfigXInfoTypeTransformationsXTransformationsXPrimitiveTransformationXCryptoReplaceFfxFpeConfigXCryptoKeyXKmsWrapped = DataLossPreventionDeidentifyTemplateXDeidentifyConfigXInfoTypeTransformationsXTransformationsXPrimitiveTransformationXCryptoReplaceFfxFpeConfigXCryptoKeyXKmsWrapped

@typing_extensions.final
class DataLossPreventionDeidentifyTemplateXDeidentifyConfigXInfoTypeTransformationsXTransformationsXPrimitiveTransformationXCryptoReplaceFfxFpeConfigXCryptoKeyXTransient(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    name: builtins.str
    def __init__(
        self,
        *,
        name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name"]) -> None: ...

global___DataLossPreventionDeidentifyTemplateXDeidentifyConfigXInfoTypeTransformationsXTransformationsXPrimitiveTransformationXCryptoReplaceFfxFpeConfigXCryptoKeyXTransient = DataLossPreventionDeidentifyTemplateXDeidentifyConfigXInfoTypeTransformationsXTransformationsXPrimitiveTransformationXCryptoReplaceFfxFpeConfigXCryptoKeyXTransient

@typing_extensions.final
class DataLossPreventionDeidentifyTemplateXDeidentifyConfigXInfoTypeTransformationsXTransformationsXPrimitiveTransformationXCryptoReplaceFfxFpeConfigXCryptoKeyXUnwrapped(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    KEY_FIELD_NUMBER: builtins.int
    key: builtins.str
    def __init__(
        self,
        *,
        key: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["key", b"key"]) -> None: ...

global___DataLossPreventionDeidentifyTemplateXDeidentifyConfigXInfoTypeTransformationsXTransformationsXPrimitiveTransformationXCryptoReplaceFfxFpeConfigXCryptoKeyXUnwrapped = DataLossPreventionDeidentifyTemplateXDeidentifyConfigXInfoTypeTransformationsXTransformationsXPrimitiveTransformationXCryptoReplaceFfxFpeConfigXCryptoKeyXUnwrapped

@typing_extensions.final
class DataLossPreventionDeidentifyTemplateXDeidentifyConfigXInfoTypeTransformationsXTransformationsXPrimitiveTransformationXCryptoReplaceFfxFpeConfigXCryptoKey(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    KMS_WRAPPED_FIELD_NUMBER: builtins.int
    TRANSIENT_FIELD_NUMBER: builtins.int
    UNWRAPPED_FIELD_NUMBER: builtins.int
    @property
    def kms_wrapped(self) -> global___DataLossPreventionDeidentifyTemplateXDeidentifyConfigXInfoTypeTransformationsXTransformationsXPrimitiveTransformationXCryptoReplaceFfxFpeConfigXCryptoKeyXKmsWrapped: ...
    @property
    def transient(self) -> global___DataLossPreventionDeidentifyTemplateXDeidentifyConfigXInfoTypeTransformationsXTransformationsXPrimitiveTransformationXCryptoReplaceFfxFpeConfigXCryptoKeyXTransient: ...
    @property
    def unwrapped(self) -> global___DataLossPreventionDeidentifyTemplateXDeidentifyConfigXInfoTypeTransformationsXTransformationsXPrimitiveTransformationXCryptoReplaceFfxFpeConfigXCryptoKeyXUnwrapped: ...
    def __init__(
        self,
        *,
        kms_wrapped: global___DataLossPreventionDeidentifyTemplateXDeidentifyConfigXInfoTypeTransformationsXTransformationsXPrimitiveTransformationXCryptoReplaceFfxFpeConfigXCryptoKeyXKmsWrapped | None = ...,
        transient: global___DataLossPreventionDeidentifyTemplateXDeidentifyConfigXInfoTypeTransformationsXTransformationsXPrimitiveTransformationXCryptoReplaceFfxFpeConfigXCryptoKeyXTransient | None = ...,
        unwrapped: global___DataLossPreventionDeidentifyTemplateXDeidentifyConfigXInfoTypeTransformationsXTransformationsXPrimitiveTransformationXCryptoReplaceFfxFpeConfigXCryptoKeyXUnwrapped | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["kms_wrapped", b"kms_wrapped", "transient", b"transient", "unwrapped", b"unwrapped"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["kms_wrapped", b"kms_wrapped", "transient", b"transient", "unwrapped", b"unwrapped"]) -> None: ...

global___DataLossPreventionDeidentifyTemplateXDeidentifyConfigXInfoTypeTransformationsXTransformationsXPrimitiveTransformationXCryptoReplaceFfxFpeConfigXCryptoKey = DataLossPreventionDeidentifyTemplateXDeidentifyConfigXInfoTypeTransformationsXTransformationsXPrimitiveTransformationXCryptoReplaceFfxFpeConfigXCryptoKey

@typing_extensions.final
class DataLossPreventionDeidentifyTemplateXDeidentifyConfigXInfoTypeTransformationsXTransformationsXPrimitiveTransformationXCryptoReplaceFfxFpeConfigXSurrogateInfoType(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    name: builtins.str
    def __init__(
        self,
        *,
        name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name"]) -> None: ...

global___DataLossPreventionDeidentifyTemplateXDeidentifyConfigXInfoTypeTransformationsXTransformationsXPrimitiveTransformationXCryptoReplaceFfxFpeConfigXSurrogateInfoType = DataLossPreventionDeidentifyTemplateXDeidentifyConfigXInfoTypeTransformationsXTransformationsXPrimitiveTransformationXCryptoReplaceFfxFpeConfigXSurrogateInfoType

@typing_extensions.final
class DataLossPreventionDeidentifyTemplateXDeidentifyConfigXInfoTypeTransformationsXTransformationsXPrimitiveTransformationXCryptoReplaceFfxFpeConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    COMMON_ALPHABET_FIELD_NUMBER: builtins.int
    CUSTOM_ALPHABET_FIELD_NUMBER: builtins.int
    RADIX_FIELD_NUMBER: builtins.int
    CONTEXT_FIELD_NUMBER: builtins.int
    CRYPTO_KEY_FIELD_NUMBER: builtins.int
    SURROGATE_INFO_TYPE_FIELD_NUMBER: builtins.int
    common_alphabet: builtins.str
    custom_alphabet: builtins.str
    radix: builtins.float
    @property
    def context(self) -> global___DataLossPreventionDeidentifyTemplateXDeidentifyConfigXInfoTypeTransformationsXTransformationsXPrimitiveTransformationXCryptoReplaceFfxFpeConfigXContext: ...
    @property
    def crypto_key(self) -> global___DataLossPreventionDeidentifyTemplateXDeidentifyConfigXInfoTypeTransformationsXTransformationsXPrimitiveTransformationXCryptoReplaceFfxFpeConfigXCryptoKey: ...
    @property
    def surrogate_info_type(self) -> global___DataLossPreventionDeidentifyTemplateXDeidentifyConfigXInfoTypeTransformationsXTransformationsXPrimitiveTransformationXCryptoReplaceFfxFpeConfigXSurrogateInfoType: ...
    def __init__(
        self,
        *,
        common_alphabet: builtins.str = ...,
        custom_alphabet: builtins.str = ...,
        radix: builtins.float = ...,
        context: global___DataLossPreventionDeidentifyTemplateXDeidentifyConfigXInfoTypeTransformationsXTransformationsXPrimitiveTransformationXCryptoReplaceFfxFpeConfigXContext | None = ...,
        crypto_key: global___DataLossPreventionDeidentifyTemplateXDeidentifyConfigXInfoTypeTransformationsXTransformationsXPrimitiveTransformationXCryptoReplaceFfxFpeConfigXCryptoKey | None = ...,
        surrogate_info_type: global___DataLossPreventionDeidentifyTemplateXDeidentifyConfigXInfoTypeTransformationsXTransformationsXPrimitiveTransformationXCryptoReplaceFfxFpeConfigXSurrogateInfoType | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["context", b"context", "crypto_key", b"crypto_key", "surrogate_info_type", b"surrogate_info_type"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["common_alphabet", b"common_alphabet", "context", b"context", "crypto_key", b"crypto_key", "custom_alphabet", b"custom_alphabet", "radix", b"radix", "surrogate_info_type", b"surrogate_info_type"]) -> None: ...

global___DataLossPreventionDeidentifyTemplateXDeidentifyConfigXInfoTypeTransformationsXTransformationsXPrimitiveTransformationXCryptoReplaceFfxFpeConfig = DataLossPreventionDeidentifyTemplateXDeidentifyConfigXInfoTypeTransformationsXTransformationsXPrimitiveTransformationXCryptoReplaceFfxFpeConfig

@typing_extensions.final
class DataLossPreventionDeidentifyTemplateXDeidentifyConfigXInfoTypeTransformationsXTransformationsXPrimitiveTransformationXReplaceConfigXNewValueXDateValue(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DAY_FIELD_NUMBER: builtins.int
    MONTH_FIELD_NUMBER: builtins.int
    YEAR_FIELD_NUMBER: builtins.int
    day: builtins.float
    month: builtins.float
    year: builtins.float
    def __init__(
        self,
        *,
        day: builtins.float = ...,
        month: builtins.float = ...,
        year: builtins.float = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["day", b"day", "month", b"month", "year", b"year"]) -> None: ...

global___DataLossPreventionDeidentifyTemplateXDeidentifyConfigXInfoTypeTransformationsXTransformationsXPrimitiveTransformationXReplaceConfigXNewValueXDateValue = DataLossPreventionDeidentifyTemplateXDeidentifyConfigXInfoTypeTransformationsXTransformationsXPrimitiveTransformationXReplaceConfigXNewValueXDateValue

@typing_extensions.final
class DataLossPreventionDeidentifyTemplateXDeidentifyConfigXInfoTypeTransformationsXTransformationsXPrimitiveTransformationXReplaceConfigXNewValueXTimeValue(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    HOURS_FIELD_NUMBER: builtins.int
    MINUTES_FIELD_NUMBER: builtins.int
    NANOS_FIELD_NUMBER: builtins.int
    SECONDS_FIELD_NUMBER: builtins.int
    hours: builtins.float
    minutes: builtins.float
    nanos: builtins.float
    seconds: builtins.float
    def __init__(
        self,
        *,
        hours: builtins.float = ...,
        minutes: builtins.float = ...,
        nanos: builtins.float = ...,
        seconds: builtins.float = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["hours", b"hours", "minutes", b"minutes", "nanos", b"nanos", "seconds", b"seconds"]) -> None: ...

global___DataLossPreventionDeidentifyTemplateXDeidentifyConfigXInfoTypeTransformationsXTransformationsXPrimitiveTransformationXReplaceConfigXNewValueXTimeValue = DataLossPreventionDeidentifyTemplateXDeidentifyConfigXInfoTypeTransformationsXTransformationsXPrimitiveTransformationXReplaceConfigXNewValueXTimeValue

@typing_extensions.final
class DataLossPreventionDeidentifyTemplateXDeidentifyConfigXInfoTypeTransformationsXTransformationsXPrimitiveTransformationXReplaceConfigXNewValue(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BOOLEAN_VALUE_FIELD_NUMBER: builtins.int
    DAY_OF_WEEK_VALUE_FIELD_NUMBER: builtins.int
    FLOAT_VALUE_FIELD_NUMBER: builtins.int
    INTEGER_VALUE_FIELD_NUMBER: builtins.int
    STRING_VALUE_FIELD_NUMBER: builtins.int
    TIMESTAMP_VALUE_FIELD_NUMBER: builtins.int
    DATE_VALUE_FIELD_NUMBER: builtins.int
    TIME_VALUE_FIELD_NUMBER: builtins.int
    boolean_value: builtins.bool
    day_of_week_value: builtins.str
    float_value: builtins.float
    integer_value: builtins.float
    string_value: builtins.str
    timestamp_value: builtins.str
    @property
    def date_value(self) -> global___DataLossPreventionDeidentifyTemplateXDeidentifyConfigXInfoTypeTransformationsXTransformationsXPrimitiveTransformationXReplaceConfigXNewValueXDateValue: ...
    @property
    def time_value(self) -> global___DataLossPreventionDeidentifyTemplateXDeidentifyConfigXInfoTypeTransformationsXTransformationsXPrimitiveTransformationXReplaceConfigXNewValueXTimeValue: ...
    def __init__(
        self,
        *,
        boolean_value: builtins.bool = ...,
        day_of_week_value: builtins.str = ...,
        float_value: builtins.float = ...,
        integer_value: builtins.float = ...,
        string_value: builtins.str = ...,
        timestamp_value: builtins.str = ...,
        date_value: global___DataLossPreventionDeidentifyTemplateXDeidentifyConfigXInfoTypeTransformationsXTransformationsXPrimitiveTransformationXReplaceConfigXNewValueXDateValue | None = ...,
        time_value: global___DataLossPreventionDeidentifyTemplateXDeidentifyConfigXInfoTypeTransformationsXTransformationsXPrimitiveTransformationXReplaceConfigXNewValueXTimeValue | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["date_value", b"date_value", "time_value", b"time_value"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["boolean_value", b"boolean_value", "date_value", b"date_value", "day_of_week_value", b"day_of_week_value", "float_value", b"float_value", "integer_value", b"integer_value", "string_value", b"string_value", "time_value", b"time_value", "timestamp_value", b"timestamp_value"]) -> None: ...

global___DataLossPreventionDeidentifyTemplateXDeidentifyConfigXInfoTypeTransformationsXTransformationsXPrimitiveTransformationXReplaceConfigXNewValue = DataLossPreventionDeidentifyTemplateXDeidentifyConfigXInfoTypeTransformationsXTransformationsXPrimitiveTransformationXReplaceConfigXNewValue

@typing_extensions.final
class DataLossPreventionDeidentifyTemplateXDeidentifyConfigXInfoTypeTransformationsXTransformationsXPrimitiveTransformationXReplaceConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NEW_VALUE_FIELD_NUMBER: builtins.int
    @property
    def new_value(self) -> global___DataLossPreventionDeidentifyTemplateXDeidentifyConfigXInfoTypeTransformationsXTransformationsXPrimitiveTransformationXReplaceConfigXNewValue: ...
    def __init__(
        self,
        *,
        new_value: global___DataLossPreventionDeidentifyTemplateXDeidentifyConfigXInfoTypeTransformationsXTransformationsXPrimitiveTransformationXReplaceConfigXNewValue | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["new_value", b"new_value"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["new_value", b"new_value"]) -> None: ...

global___DataLossPreventionDeidentifyTemplateXDeidentifyConfigXInfoTypeTransformationsXTransformationsXPrimitiveTransformationXReplaceConfig = DataLossPreventionDeidentifyTemplateXDeidentifyConfigXInfoTypeTransformationsXTransformationsXPrimitiveTransformationXReplaceConfig

@typing_extensions.final
class DataLossPreventionDeidentifyTemplateXDeidentifyConfigXInfoTypeTransformationsXTransformationsXPrimitiveTransformation(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    REPLACE_WITH_INFO_TYPE_CONFIG_FIELD_NUMBER: builtins.int
    CHARACTER_MASK_CONFIG_FIELD_NUMBER: builtins.int
    CRYPTO_DETERMINISTIC_CONFIG_FIELD_NUMBER: builtins.int
    CRYPTO_REPLACE_FFX_FPE_CONFIG_FIELD_NUMBER: builtins.int
    REPLACE_CONFIG_FIELD_NUMBER: builtins.int
    replace_with_info_type_config: builtins.bool
    @property
    def character_mask_config(self) -> global___DataLossPreventionDeidentifyTemplateXDeidentifyConfigXInfoTypeTransformationsXTransformationsXPrimitiveTransformationXCharacterMaskConfig: ...
    @property
    def crypto_deterministic_config(self) -> global___DataLossPreventionDeidentifyTemplateXDeidentifyConfigXInfoTypeTransformationsXTransformationsXPrimitiveTransformationXCryptoDeterministicConfig: ...
    @property
    def crypto_replace_ffx_fpe_config(self) -> global___DataLossPreventionDeidentifyTemplateXDeidentifyConfigXInfoTypeTransformationsXTransformationsXPrimitiveTransformationXCryptoReplaceFfxFpeConfig: ...
    @property
    def replace_config(self) -> global___DataLossPreventionDeidentifyTemplateXDeidentifyConfigXInfoTypeTransformationsXTransformationsXPrimitiveTransformationXReplaceConfig: ...
    def __init__(
        self,
        *,
        replace_with_info_type_config: builtins.bool = ...,
        character_mask_config: global___DataLossPreventionDeidentifyTemplateXDeidentifyConfigXInfoTypeTransformationsXTransformationsXPrimitiveTransformationXCharacterMaskConfig | None = ...,
        crypto_deterministic_config: global___DataLossPreventionDeidentifyTemplateXDeidentifyConfigXInfoTypeTransformationsXTransformationsXPrimitiveTransformationXCryptoDeterministicConfig | None = ...,
        crypto_replace_ffx_fpe_config: global___DataLossPreventionDeidentifyTemplateXDeidentifyConfigXInfoTypeTransformationsXTransformationsXPrimitiveTransformationXCryptoReplaceFfxFpeConfig | None = ...,
        replace_config: global___DataLossPreventionDeidentifyTemplateXDeidentifyConfigXInfoTypeTransformationsXTransformationsXPrimitiveTransformationXReplaceConfig | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["character_mask_config", b"character_mask_config", "crypto_deterministic_config", b"crypto_deterministic_config", "crypto_replace_ffx_fpe_config", b"crypto_replace_ffx_fpe_config", "replace_config", b"replace_config"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["character_mask_config", b"character_mask_config", "crypto_deterministic_config", b"crypto_deterministic_config", "crypto_replace_ffx_fpe_config", b"crypto_replace_ffx_fpe_config", "replace_config", b"replace_config", "replace_with_info_type_config", b"replace_with_info_type_config"]) -> None: ...

global___DataLossPreventionDeidentifyTemplateXDeidentifyConfigXInfoTypeTransformationsXTransformationsXPrimitiveTransformation = DataLossPreventionDeidentifyTemplateXDeidentifyConfigXInfoTypeTransformationsXTransformationsXPrimitiveTransformation

@typing_extensions.final
class DataLossPreventionDeidentifyTemplateXDeidentifyConfigXInfoTypeTransformationsXTransformations(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_TYPES_FIELD_NUMBER: builtins.int
    PRIMITIVE_TRANSFORMATION_FIELD_NUMBER: builtins.int
    @property
    def info_types(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DataLossPreventionDeidentifyTemplateXDeidentifyConfigXInfoTypeTransformationsXTransformationsXInfoTypes]: ...
    @property
    def primitive_transformation(self) -> global___DataLossPreventionDeidentifyTemplateXDeidentifyConfigXInfoTypeTransformationsXTransformationsXPrimitiveTransformation: ...
    def __init__(
        self,
        *,
        info_types: collections.abc.Iterable[global___DataLossPreventionDeidentifyTemplateXDeidentifyConfigXInfoTypeTransformationsXTransformationsXInfoTypes] | None = ...,
        primitive_transformation: global___DataLossPreventionDeidentifyTemplateXDeidentifyConfigXInfoTypeTransformationsXTransformationsXPrimitiveTransformation | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["primitive_transformation", b"primitive_transformation"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["info_types", b"info_types", "primitive_transformation", b"primitive_transformation"]) -> None: ...

global___DataLossPreventionDeidentifyTemplateXDeidentifyConfigXInfoTypeTransformationsXTransformations = DataLossPreventionDeidentifyTemplateXDeidentifyConfigXInfoTypeTransformationsXTransformations

@typing_extensions.final
class DataLossPreventionDeidentifyTemplateXDeidentifyConfigXInfoTypeTransformations(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TRANSFORMATIONS_FIELD_NUMBER: builtins.int
    @property
    def transformations(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DataLossPreventionDeidentifyTemplateXDeidentifyConfigXInfoTypeTransformationsXTransformations]: ...
    def __init__(
        self,
        *,
        transformations: collections.abc.Iterable[global___DataLossPreventionDeidentifyTemplateXDeidentifyConfigXInfoTypeTransformationsXTransformations] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["transformations", b"transformations"]) -> None: ...

global___DataLossPreventionDeidentifyTemplateXDeidentifyConfigXInfoTypeTransformations = DataLossPreventionDeidentifyTemplateXDeidentifyConfigXInfoTypeTransformations

@typing_extensions.final
class DataLossPreventionDeidentifyTemplateXDeidentifyConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_TYPE_TRANSFORMATIONS_FIELD_NUMBER: builtins.int
    @property
    def info_type_transformations(self) -> global___DataLossPreventionDeidentifyTemplateXDeidentifyConfigXInfoTypeTransformations: ...
    def __init__(
        self,
        *,
        info_type_transformations: global___DataLossPreventionDeidentifyTemplateXDeidentifyConfigXInfoTypeTransformations | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["info_type_transformations", b"info_type_transformations"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["info_type_transformations", b"info_type_transformations"]) -> None: ...

global___DataLossPreventionDeidentifyTemplateXDeidentifyConfig = DataLossPreventionDeidentifyTemplateXDeidentifyConfig

@typing_extensions.final
class DataLossPreventionDeidentifyTemplateXTimeouts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_FIELD_NUMBER: builtins.int
    DELETE_FIELD_NUMBER: builtins.int
    UPDATE_FIELD_NUMBER: builtins.int
    create: builtins.str
    delete: builtins.str
    update: builtins.str
    def __init__(
        self,
        *,
        create: builtins.str = ...,
        delete: builtins.str = ...,
        update: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["create", b"create", "delete", b"delete", "update", b"update"]) -> None: ...

global___DataLossPreventionDeidentifyTemplateXTimeouts = DataLossPreventionDeidentifyTemplateXTimeouts

@typing_extensions.final
class DataLossPreventionDeidentifyTemplate(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DESCRIPTION_FIELD_NUMBER: builtins.int
    DISPLAY_NAME_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    PARENT_FIELD_NUMBER: builtins.int
    DEIDENTIFY_CONFIG_FIELD_NUMBER: builtins.int
    TIMEOUTS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    description: builtins.str
    display_name: builtins.str
    id: builtins.str
    name: builtins.str
    parent: builtins.str
    @property
    def deidentify_config(self) -> global___DataLossPreventionDeidentifyTemplateXDeidentifyConfig: ...
    @property
    def timeouts(self) -> global___DataLossPreventionDeidentifyTemplateXTimeouts: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        description: builtins.str = ...,
        display_name: builtins.str = ...,
        id: builtins.str = ...,
        name: builtins.str = ...,
        parent: builtins.str = ...,
        deidentify_config: global___DataLossPreventionDeidentifyTemplateXDeidentifyConfig | None = ...,
        timeouts: global___DataLossPreventionDeidentifyTemplateXTimeouts | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["deidentify_config", b"deidentify_config", "resource_info", b"resource_info", "timeouts", b"timeouts"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["deidentify_config", b"deidentify_config", "description", b"description", "display_name", b"display_name", "id", b"id", "name", b"name", "parent", b"parent", "resource_info", b"resource_info", "timeouts", b"timeouts"]) -> None: ...

global___DataLossPreventionDeidentifyTemplate = DataLossPreventionDeidentifyTemplate

@typing_extensions.final
class DataLossPreventionInspectTemplateXInspectConfigXCustomInfoTypesXDictionaryXCloudStoragePath(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PATH_FIELD_NUMBER: builtins.int
    path: builtins.str
    def __init__(
        self,
        *,
        path: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["path", b"path"]) -> None: ...

global___DataLossPreventionInspectTemplateXInspectConfigXCustomInfoTypesXDictionaryXCloudStoragePath = DataLossPreventionInspectTemplateXInspectConfigXCustomInfoTypesXDictionaryXCloudStoragePath

@typing_extensions.final
class DataLossPreventionInspectTemplateXInspectConfigXCustomInfoTypesXDictionaryXWordList(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    WORDS_FIELD_NUMBER: builtins.int
    @property
    def words(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    def __init__(
        self,
        *,
        words: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["words", b"words"]) -> None: ...

global___DataLossPreventionInspectTemplateXInspectConfigXCustomInfoTypesXDictionaryXWordList = DataLossPreventionInspectTemplateXInspectConfigXCustomInfoTypesXDictionaryXWordList

@typing_extensions.final
class DataLossPreventionInspectTemplateXInspectConfigXCustomInfoTypesXDictionary(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLOUD_STORAGE_PATH_FIELD_NUMBER: builtins.int
    WORD_LIST_FIELD_NUMBER: builtins.int
    @property
    def cloud_storage_path(self) -> global___DataLossPreventionInspectTemplateXInspectConfigXCustomInfoTypesXDictionaryXCloudStoragePath: ...
    @property
    def word_list(self) -> global___DataLossPreventionInspectTemplateXInspectConfigXCustomInfoTypesXDictionaryXWordList: ...
    def __init__(
        self,
        *,
        cloud_storage_path: global___DataLossPreventionInspectTemplateXInspectConfigXCustomInfoTypesXDictionaryXCloudStoragePath | None = ...,
        word_list: global___DataLossPreventionInspectTemplateXInspectConfigXCustomInfoTypesXDictionaryXWordList | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["cloud_storage_path", b"cloud_storage_path", "word_list", b"word_list"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["cloud_storage_path", b"cloud_storage_path", "word_list", b"word_list"]) -> None: ...

global___DataLossPreventionInspectTemplateXInspectConfigXCustomInfoTypesXDictionary = DataLossPreventionInspectTemplateXInspectConfigXCustomInfoTypesXDictionary

@typing_extensions.final
class DataLossPreventionInspectTemplateXInspectConfigXCustomInfoTypesXInfoType(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    name: builtins.str
    def __init__(
        self,
        *,
        name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name"]) -> None: ...

global___DataLossPreventionInspectTemplateXInspectConfigXCustomInfoTypesXInfoType = DataLossPreventionInspectTemplateXInspectConfigXCustomInfoTypesXInfoType

@typing_extensions.final
class DataLossPreventionInspectTemplateXInspectConfigXCustomInfoTypesXRegex(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    GROUP_INDEXES_FIELD_NUMBER: builtins.int
    PATTERN_FIELD_NUMBER: builtins.int
    @property
    def group_indexes(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.float]: ...
    pattern: builtins.str
    def __init__(
        self,
        *,
        group_indexes: collections.abc.Iterable[builtins.float] | None = ...,
        pattern: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["group_indexes", b"group_indexes", "pattern", b"pattern"]) -> None: ...

global___DataLossPreventionInspectTemplateXInspectConfigXCustomInfoTypesXRegex = DataLossPreventionInspectTemplateXInspectConfigXCustomInfoTypesXRegex

@typing_extensions.final
class DataLossPreventionInspectTemplateXInspectConfigXCustomInfoTypesXStoredType(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    name: builtins.str
    def __init__(
        self,
        *,
        name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name"]) -> None: ...

global___DataLossPreventionInspectTemplateXInspectConfigXCustomInfoTypesXStoredType = DataLossPreventionInspectTemplateXInspectConfigXCustomInfoTypesXStoredType

@typing_extensions.final
class DataLossPreventionInspectTemplateXInspectConfigXCustomInfoTypes(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EXCLUSION_TYPE_FIELD_NUMBER: builtins.int
    LIKELIHOOD_FIELD_NUMBER: builtins.int
    DICTIONARY_FIELD_NUMBER: builtins.int
    INFO_TYPE_FIELD_NUMBER: builtins.int
    REGEX_FIELD_NUMBER: builtins.int
    STORED_TYPE_FIELD_NUMBER: builtins.int
    exclusion_type: builtins.str
    likelihood: builtins.str
    @property
    def dictionary(self) -> global___DataLossPreventionInspectTemplateXInspectConfigXCustomInfoTypesXDictionary: ...
    @property
    def info_type(self) -> global___DataLossPreventionInspectTemplateXInspectConfigXCustomInfoTypesXInfoType: ...
    @property
    def regex(self) -> global___DataLossPreventionInspectTemplateXInspectConfigXCustomInfoTypesXRegex: ...
    @property
    def stored_type(self) -> global___DataLossPreventionInspectTemplateXInspectConfigXCustomInfoTypesXStoredType: ...
    def __init__(
        self,
        *,
        exclusion_type: builtins.str = ...,
        likelihood: builtins.str = ...,
        dictionary: global___DataLossPreventionInspectTemplateXInspectConfigXCustomInfoTypesXDictionary | None = ...,
        info_type: global___DataLossPreventionInspectTemplateXInspectConfigXCustomInfoTypesXInfoType | None = ...,
        regex: global___DataLossPreventionInspectTemplateXInspectConfigXCustomInfoTypesXRegex | None = ...,
        stored_type: global___DataLossPreventionInspectTemplateXInspectConfigXCustomInfoTypesXStoredType | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["dictionary", b"dictionary", "info_type", b"info_type", "regex", b"regex", "stored_type", b"stored_type"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["dictionary", b"dictionary", "exclusion_type", b"exclusion_type", "info_type", b"info_type", "likelihood", b"likelihood", "regex", b"regex", "stored_type", b"stored_type"]) -> None: ...

global___DataLossPreventionInspectTemplateXInspectConfigXCustomInfoTypes = DataLossPreventionInspectTemplateXInspectConfigXCustomInfoTypes

@typing_extensions.final
class DataLossPreventionInspectTemplateXInspectConfigXInfoTypes(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    name: builtins.str
    def __init__(
        self,
        *,
        name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name"]) -> None: ...

global___DataLossPreventionInspectTemplateXInspectConfigXInfoTypes = DataLossPreventionInspectTemplateXInspectConfigXInfoTypes

@typing_extensions.final
class DataLossPreventionInspectTemplateXInspectConfigXLimitsXMaxFindingsPerInfoTypeXInfoType(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    name: builtins.str
    def __init__(
        self,
        *,
        name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name"]) -> None: ...

global___DataLossPreventionInspectTemplateXInspectConfigXLimitsXMaxFindingsPerInfoTypeXInfoType = DataLossPreventionInspectTemplateXInspectConfigXLimitsXMaxFindingsPerInfoTypeXInfoType

@typing_extensions.final
class DataLossPreventionInspectTemplateXInspectConfigXLimitsXMaxFindingsPerInfoType(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MAX_FINDINGS_FIELD_NUMBER: builtins.int
    INFO_TYPE_FIELD_NUMBER: builtins.int
    max_findings: builtins.float
    @property
    def info_type(self) -> global___DataLossPreventionInspectTemplateXInspectConfigXLimitsXMaxFindingsPerInfoTypeXInfoType: ...
    def __init__(
        self,
        *,
        max_findings: builtins.float = ...,
        info_type: global___DataLossPreventionInspectTemplateXInspectConfigXLimitsXMaxFindingsPerInfoTypeXInfoType | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["info_type", b"info_type"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["info_type", b"info_type", "max_findings", b"max_findings"]) -> None: ...

global___DataLossPreventionInspectTemplateXInspectConfigXLimitsXMaxFindingsPerInfoType = DataLossPreventionInspectTemplateXInspectConfigXLimitsXMaxFindingsPerInfoType

@typing_extensions.final
class DataLossPreventionInspectTemplateXInspectConfigXLimits(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MAX_FINDINGS_PER_ITEM_FIELD_NUMBER: builtins.int
    MAX_FINDINGS_PER_REQUEST_FIELD_NUMBER: builtins.int
    MAX_FINDINGS_PER_INFO_TYPE_FIELD_NUMBER: builtins.int
    max_findings_per_item: builtins.float
    max_findings_per_request: builtins.float
    @property
    def max_findings_per_info_type(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DataLossPreventionInspectTemplateXInspectConfigXLimitsXMaxFindingsPerInfoType]: ...
    def __init__(
        self,
        *,
        max_findings_per_item: builtins.float = ...,
        max_findings_per_request: builtins.float = ...,
        max_findings_per_info_type: collections.abc.Iterable[global___DataLossPreventionInspectTemplateXInspectConfigXLimitsXMaxFindingsPerInfoType] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["max_findings_per_info_type", b"max_findings_per_info_type", "max_findings_per_item", b"max_findings_per_item", "max_findings_per_request", b"max_findings_per_request"]) -> None: ...

global___DataLossPreventionInspectTemplateXInspectConfigXLimits = DataLossPreventionInspectTemplateXInspectConfigXLimits

@typing_extensions.final
class DataLossPreventionInspectTemplateXInspectConfigXRuleSetXInfoTypes(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    name: builtins.str
    def __init__(
        self,
        *,
        name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name"]) -> None: ...

global___DataLossPreventionInspectTemplateXInspectConfigXRuleSetXInfoTypes = DataLossPreventionInspectTemplateXInspectConfigXRuleSetXInfoTypes

@typing_extensions.final
class DataLossPreventionInspectTemplateXInspectConfigXRuleSetXRulesXExclusionRuleXDictionaryXCloudStoragePath(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PATH_FIELD_NUMBER: builtins.int
    path: builtins.str
    def __init__(
        self,
        *,
        path: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["path", b"path"]) -> None: ...

global___DataLossPreventionInspectTemplateXInspectConfigXRuleSetXRulesXExclusionRuleXDictionaryXCloudStoragePath = DataLossPreventionInspectTemplateXInspectConfigXRuleSetXRulesXExclusionRuleXDictionaryXCloudStoragePath

@typing_extensions.final
class DataLossPreventionInspectTemplateXInspectConfigXRuleSetXRulesXExclusionRuleXDictionaryXWordList(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    WORDS_FIELD_NUMBER: builtins.int
    @property
    def words(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    def __init__(
        self,
        *,
        words: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["words", b"words"]) -> None: ...

global___DataLossPreventionInspectTemplateXInspectConfigXRuleSetXRulesXExclusionRuleXDictionaryXWordList = DataLossPreventionInspectTemplateXInspectConfigXRuleSetXRulesXExclusionRuleXDictionaryXWordList

@typing_extensions.final
class DataLossPreventionInspectTemplateXInspectConfigXRuleSetXRulesXExclusionRuleXDictionary(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLOUD_STORAGE_PATH_FIELD_NUMBER: builtins.int
    WORD_LIST_FIELD_NUMBER: builtins.int
    @property
    def cloud_storage_path(self) -> global___DataLossPreventionInspectTemplateXInspectConfigXRuleSetXRulesXExclusionRuleXDictionaryXCloudStoragePath: ...
    @property
    def word_list(self) -> global___DataLossPreventionInspectTemplateXInspectConfigXRuleSetXRulesXExclusionRuleXDictionaryXWordList: ...
    def __init__(
        self,
        *,
        cloud_storage_path: global___DataLossPreventionInspectTemplateXInspectConfigXRuleSetXRulesXExclusionRuleXDictionaryXCloudStoragePath | None = ...,
        word_list: global___DataLossPreventionInspectTemplateXInspectConfigXRuleSetXRulesXExclusionRuleXDictionaryXWordList | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["cloud_storage_path", b"cloud_storage_path", "word_list", b"word_list"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["cloud_storage_path", b"cloud_storage_path", "word_list", b"word_list"]) -> None: ...

global___DataLossPreventionInspectTemplateXInspectConfigXRuleSetXRulesXExclusionRuleXDictionary = DataLossPreventionInspectTemplateXInspectConfigXRuleSetXRulesXExclusionRuleXDictionary

@typing_extensions.final
class DataLossPreventionInspectTemplateXInspectConfigXRuleSetXRulesXExclusionRuleXExcludeInfoTypesXInfoTypes(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    name: builtins.str
    def __init__(
        self,
        *,
        name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name"]) -> None: ...

global___DataLossPreventionInspectTemplateXInspectConfigXRuleSetXRulesXExclusionRuleXExcludeInfoTypesXInfoTypes = DataLossPreventionInspectTemplateXInspectConfigXRuleSetXRulesXExclusionRuleXExcludeInfoTypesXInfoTypes

@typing_extensions.final
class DataLossPreventionInspectTemplateXInspectConfigXRuleSetXRulesXExclusionRuleXExcludeInfoTypes(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_TYPES_FIELD_NUMBER: builtins.int
    @property
    def info_types(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DataLossPreventionInspectTemplateXInspectConfigXRuleSetXRulesXExclusionRuleXExcludeInfoTypesXInfoTypes]: ...
    def __init__(
        self,
        *,
        info_types: collections.abc.Iterable[global___DataLossPreventionInspectTemplateXInspectConfigXRuleSetXRulesXExclusionRuleXExcludeInfoTypesXInfoTypes] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["info_types", b"info_types"]) -> None: ...

global___DataLossPreventionInspectTemplateXInspectConfigXRuleSetXRulesXExclusionRuleXExcludeInfoTypes = DataLossPreventionInspectTemplateXInspectConfigXRuleSetXRulesXExclusionRuleXExcludeInfoTypes

@typing_extensions.final
class DataLossPreventionInspectTemplateXInspectConfigXRuleSetXRulesXExclusionRuleXRegex(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    GROUP_INDEXES_FIELD_NUMBER: builtins.int
    PATTERN_FIELD_NUMBER: builtins.int
    @property
    def group_indexes(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.float]: ...
    pattern: builtins.str
    def __init__(
        self,
        *,
        group_indexes: collections.abc.Iterable[builtins.float] | None = ...,
        pattern: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["group_indexes", b"group_indexes", "pattern", b"pattern"]) -> None: ...

global___DataLossPreventionInspectTemplateXInspectConfigXRuleSetXRulesXExclusionRuleXRegex = DataLossPreventionInspectTemplateXInspectConfigXRuleSetXRulesXExclusionRuleXRegex

@typing_extensions.final
class DataLossPreventionInspectTemplateXInspectConfigXRuleSetXRulesXExclusionRule(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MATCHING_TYPE_FIELD_NUMBER: builtins.int
    DICTIONARY_FIELD_NUMBER: builtins.int
    EXCLUDE_INFO_TYPES_FIELD_NUMBER: builtins.int
    REGEX_FIELD_NUMBER: builtins.int
    matching_type: builtins.str
    @property
    def dictionary(self) -> global___DataLossPreventionInspectTemplateXInspectConfigXRuleSetXRulesXExclusionRuleXDictionary: ...
    @property
    def exclude_info_types(self) -> global___DataLossPreventionInspectTemplateXInspectConfigXRuleSetXRulesXExclusionRuleXExcludeInfoTypes: ...
    @property
    def regex(self) -> global___DataLossPreventionInspectTemplateXInspectConfigXRuleSetXRulesXExclusionRuleXRegex: ...
    def __init__(
        self,
        *,
        matching_type: builtins.str = ...,
        dictionary: global___DataLossPreventionInspectTemplateXInspectConfigXRuleSetXRulesXExclusionRuleXDictionary | None = ...,
        exclude_info_types: global___DataLossPreventionInspectTemplateXInspectConfigXRuleSetXRulesXExclusionRuleXExcludeInfoTypes | None = ...,
        regex: global___DataLossPreventionInspectTemplateXInspectConfigXRuleSetXRulesXExclusionRuleXRegex | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["dictionary", b"dictionary", "exclude_info_types", b"exclude_info_types", "regex", b"regex"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["dictionary", b"dictionary", "exclude_info_types", b"exclude_info_types", "matching_type", b"matching_type", "regex", b"regex"]) -> None: ...

global___DataLossPreventionInspectTemplateXInspectConfigXRuleSetXRulesXExclusionRule = DataLossPreventionInspectTemplateXInspectConfigXRuleSetXRulesXExclusionRule

@typing_extensions.final
class DataLossPreventionInspectTemplateXInspectConfigXRuleSetXRulesXHotwordRuleXHotwordRegex(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    GROUP_INDEXES_FIELD_NUMBER: builtins.int
    PATTERN_FIELD_NUMBER: builtins.int
    @property
    def group_indexes(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.float]: ...
    pattern: builtins.str
    def __init__(
        self,
        *,
        group_indexes: collections.abc.Iterable[builtins.float] | None = ...,
        pattern: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["group_indexes", b"group_indexes", "pattern", b"pattern"]) -> None: ...

global___DataLossPreventionInspectTemplateXInspectConfigXRuleSetXRulesXHotwordRuleXHotwordRegex = DataLossPreventionInspectTemplateXInspectConfigXRuleSetXRulesXHotwordRuleXHotwordRegex

@typing_extensions.final
class DataLossPreventionInspectTemplateXInspectConfigXRuleSetXRulesXHotwordRuleXLikelihoodAdjustment(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FIXED_LIKELIHOOD_FIELD_NUMBER: builtins.int
    RELATIVE_LIKELIHOOD_FIELD_NUMBER: builtins.int
    fixed_likelihood: builtins.str
    relative_likelihood: builtins.float
    def __init__(
        self,
        *,
        fixed_likelihood: builtins.str = ...,
        relative_likelihood: builtins.float = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["fixed_likelihood", b"fixed_likelihood", "relative_likelihood", b"relative_likelihood"]) -> None: ...

global___DataLossPreventionInspectTemplateXInspectConfigXRuleSetXRulesXHotwordRuleXLikelihoodAdjustment = DataLossPreventionInspectTemplateXInspectConfigXRuleSetXRulesXHotwordRuleXLikelihoodAdjustment

@typing_extensions.final
class DataLossPreventionInspectTemplateXInspectConfigXRuleSetXRulesXHotwordRuleXProximity(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    WINDOW_AFTER_FIELD_NUMBER: builtins.int
    WINDOW_BEFORE_FIELD_NUMBER: builtins.int
    window_after: builtins.float
    window_before: builtins.float
    def __init__(
        self,
        *,
        window_after: builtins.float = ...,
        window_before: builtins.float = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["window_after", b"window_after", "window_before", b"window_before"]) -> None: ...

global___DataLossPreventionInspectTemplateXInspectConfigXRuleSetXRulesXHotwordRuleXProximity = DataLossPreventionInspectTemplateXInspectConfigXRuleSetXRulesXHotwordRuleXProximity

@typing_extensions.final
class DataLossPreventionInspectTemplateXInspectConfigXRuleSetXRulesXHotwordRule(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    HOTWORD_REGEX_FIELD_NUMBER: builtins.int
    LIKELIHOOD_ADJUSTMENT_FIELD_NUMBER: builtins.int
    PROXIMITY_FIELD_NUMBER: builtins.int
    @property
    def hotword_regex(self) -> global___DataLossPreventionInspectTemplateXInspectConfigXRuleSetXRulesXHotwordRuleXHotwordRegex: ...
    @property
    def likelihood_adjustment(self) -> global___DataLossPreventionInspectTemplateXInspectConfigXRuleSetXRulesXHotwordRuleXLikelihoodAdjustment: ...
    @property
    def proximity(self) -> global___DataLossPreventionInspectTemplateXInspectConfigXRuleSetXRulesXHotwordRuleXProximity: ...
    def __init__(
        self,
        *,
        hotword_regex: global___DataLossPreventionInspectTemplateXInspectConfigXRuleSetXRulesXHotwordRuleXHotwordRegex | None = ...,
        likelihood_adjustment: global___DataLossPreventionInspectTemplateXInspectConfigXRuleSetXRulesXHotwordRuleXLikelihoodAdjustment | None = ...,
        proximity: global___DataLossPreventionInspectTemplateXInspectConfigXRuleSetXRulesXHotwordRuleXProximity | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["hotword_regex", b"hotword_regex", "likelihood_adjustment", b"likelihood_adjustment", "proximity", b"proximity"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["hotword_regex", b"hotword_regex", "likelihood_adjustment", b"likelihood_adjustment", "proximity", b"proximity"]) -> None: ...

global___DataLossPreventionInspectTemplateXInspectConfigXRuleSetXRulesXHotwordRule = DataLossPreventionInspectTemplateXInspectConfigXRuleSetXRulesXHotwordRule

@typing_extensions.final
class DataLossPreventionInspectTemplateXInspectConfigXRuleSetXRules(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EXCLUSION_RULE_FIELD_NUMBER: builtins.int
    HOTWORD_RULE_FIELD_NUMBER: builtins.int
    @property
    def exclusion_rule(self) -> global___DataLossPreventionInspectTemplateXInspectConfigXRuleSetXRulesXExclusionRule: ...
    @property
    def hotword_rule(self) -> global___DataLossPreventionInspectTemplateXInspectConfigXRuleSetXRulesXHotwordRule: ...
    def __init__(
        self,
        *,
        exclusion_rule: global___DataLossPreventionInspectTemplateXInspectConfigXRuleSetXRulesXExclusionRule | None = ...,
        hotword_rule: global___DataLossPreventionInspectTemplateXInspectConfigXRuleSetXRulesXHotwordRule | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["exclusion_rule", b"exclusion_rule", "hotword_rule", b"hotword_rule"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["exclusion_rule", b"exclusion_rule", "hotword_rule", b"hotword_rule"]) -> None: ...

global___DataLossPreventionInspectTemplateXInspectConfigXRuleSetXRules = DataLossPreventionInspectTemplateXInspectConfigXRuleSetXRules

@typing_extensions.final
class DataLossPreventionInspectTemplateXInspectConfigXRuleSet(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_TYPES_FIELD_NUMBER: builtins.int
    RULES_FIELD_NUMBER: builtins.int
    @property
    def info_types(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DataLossPreventionInspectTemplateXInspectConfigXRuleSetXInfoTypes]: ...
    @property
    def rules(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DataLossPreventionInspectTemplateXInspectConfigXRuleSetXRules]: ...
    def __init__(
        self,
        *,
        info_types: collections.abc.Iterable[global___DataLossPreventionInspectTemplateXInspectConfigXRuleSetXInfoTypes] | None = ...,
        rules: collections.abc.Iterable[global___DataLossPreventionInspectTemplateXInspectConfigXRuleSetXRules] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["info_types", b"info_types", "rules", b"rules"]) -> None: ...

global___DataLossPreventionInspectTemplateXInspectConfigXRuleSet = DataLossPreventionInspectTemplateXInspectConfigXRuleSet

@typing_extensions.final
class DataLossPreventionInspectTemplateXInspectConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CONTENT_OPTIONS_FIELD_NUMBER: builtins.int
    EXCLUDE_INFO_TYPES_FIELD_NUMBER: builtins.int
    INCLUDE_QUOTE_FIELD_NUMBER: builtins.int
    MIN_LIKELIHOOD_FIELD_NUMBER: builtins.int
    CUSTOM_INFO_TYPES_FIELD_NUMBER: builtins.int
    INFO_TYPES_FIELD_NUMBER: builtins.int
    LIMITS_FIELD_NUMBER: builtins.int
    RULE_SET_FIELD_NUMBER: builtins.int
    @property
    def content_options(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    exclude_info_types: builtins.bool
    include_quote: builtins.bool
    min_likelihood: builtins.str
    @property
    def custom_info_types(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DataLossPreventionInspectTemplateXInspectConfigXCustomInfoTypes]: ...
    @property
    def info_types(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DataLossPreventionInspectTemplateXInspectConfigXInfoTypes]: ...
    @property
    def limits(self) -> global___DataLossPreventionInspectTemplateXInspectConfigXLimits: ...
    @property
    def rule_set(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DataLossPreventionInspectTemplateXInspectConfigXRuleSet]: ...
    def __init__(
        self,
        *,
        content_options: collections.abc.Iterable[builtins.str] | None = ...,
        exclude_info_types: builtins.bool = ...,
        include_quote: builtins.bool = ...,
        min_likelihood: builtins.str = ...,
        custom_info_types: collections.abc.Iterable[global___DataLossPreventionInspectTemplateXInspectConfigXCustomInfoTypes] | None = ...,
        info_types: collections.abc.Iterable[global___DataLossPreventionInspectTemplateXInspectConfigXInfoTypes] | None = ...,
        limits: global___DataLossPreventionInspectTemplateXInspectConfigXLimits | None = ...,
        rule_set: collections.abc.Iterable[global___DataLossPreventionInspectTemplateXInspectConfigXRuleSet] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["limits", b"limits"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["content_options", b"content_options", "custom_info_types", b"custom_info_types", "exclude_info_types", b"exclude_info_types", "include_quote", b"include_quote", "info_types", b"info_types", "limits", b"limits", "min_likelihood", b"min_likelihood", "rule_set", b"rule_set"]) -> None: ...

global___DataLossPreventionInspectTemplateXInspectConfig = DataLossPreventionInspectTemplateXInspectConfig

@typing_extensions.final
class DataLossPreventionInspectTemplateXTimeouts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_FIELD_NUMBER: builtins.int
    DELETE_FIELD_NUMBER: builtins.int
    UPDATE_FIELD_NUMBER: builtins.int
    create: builtins.str
    delete: builtins.str
    update: builtins.str
    def __init__(
        self,
        *,
        create: builtins.str = ...,
        delete: builtins.str = ...,
        update: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["create", b"create", "delete", b"delete", "update", b"update"]) -> None: ...

global___DataLossPreventionInspectTemplateXTimeouts = DataLossPreventionInspectTemplateXTimeouts

@typing_extensions.final
class DataLossPreventionInspectTemplate(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DESCRIPTION_FIELD_NUMBER: builtins.int
    DISPLAY_NAME_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    PARENT_FIELD_NUMBER: builtins.int
    INSPECT_CONFIG_FIELD_NUMBER: builtins.int
    TIMEOUTS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    description: builtins.str
    display_name: builtins.str
    id: builtins.str
    name: builtins.str
    parent: builtins.str
    @property
    def inspect_config(self) -> global___DataLossPreventionInspectTemplateXInspectConfig: ...
    @property
    def timeouts(self) -> global___DataLossPreventionInspectTemplateXTimeouts: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        description: builtins.str = ...,
        display_name: builtins.str = ...,
        id: builtins.str = ...,
        name: builtins.str = ...,
        parent: builtins.str = ...,
        inspect_config: global___DataLossPreventionInspectTemplateXInspectConfig | None = ...,
        timeouts: global___DataLossPreventionInspectTemplateXTimeouts | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["inspect_config", b"inspect_config", "resource_info", b"resource_info", "timeouts", b"timeouts"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["description", b"description", "display_name", b"display_name", "id", b"id", "inspect_config", b"inspect_config", "name", b"name", "parent", b"parent", "resource_info", b"resource_info", "timeouts", b"timeouts"]) -> None: ...

global___DataLossPreventionInspectTemplate = DataLossPreventionInspectTemplate

@typing_extensions.final
class DataLossPreventionJobTriggerXInspectJobXActionsXSaveFindingsXOutputConfigXTable(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DATASET_ID_FIELD_NUMBER: builtins.int
    PROJECT_ID_FIELD_NUMBER: builtins.int
    TABLE_ID_FIELD_NUMBER: builtins.int
    dataset_id: builtins.str
    project_id: builtins.str
    table_id: builtins.str
    def __init__(
        self,
        *,
        dataset_id: builtins.str = ...,
        project_id: builtins.str = ...,
        table_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["dataset_id", b"dataset_id", "project_id", b"project_id", "table_id", b"table_id"]) -> None: ...

global___DataLossPreventionJobTriggerXInspectJobXActionsXSaveFindingsXOutputConfigXTable = DataLossPreventionJobTriggerXInspectJobXActionsXSaveFindingsXOutputConfigXTable

@typing_extensions.final
class DataLossPreventionJobTriggerXInspectJobXActionsXSaveFindingsXOutputConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    OUTPUT_SCHEMA_FIELD_NUMBER: builtins.int
    TABLE_FIELD_NUMBER: builtins.int
    output_schema: builtins.str
    @property
    def table(self) -> global___DataLossPreventionJobTriggerXInspectJobXActionsXSaveFindingsXOutputConfigXTable: ...
    def __init__(
        self,
        *,
        output_schema: builtins.str = ...,
        table: global___DataLossPreventionJobTriggerXInspectJobXActionsXSaveFindingsXOutputConfigXTable | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["table", b"table"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["output_schema", b"output_schema", "table", b"table"]) -> None: ...

global___DataLossPreventionJobTriggerXInspectJobXActionsXSaveFindingsXOutputConfig = DataLossPreventionJobTriggerXInspectJobXActionsXSaveFindingsXOutputConfig

@typing_extensions.final
class DataLossPreventionJobTriggerXInspectJobXActionsXSaveFindings(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    OUTPUT_CONFIG_FIELD_NUMBER: builtins.int
    @property
    def output_config(self) -> global___DataLossPreventionJobTriggerXInspectJobXActionsXSaveFindingsXOutputConfig: ...
    def __init__(
        self,
        *,
        output_config: global___DataLossPreventionJobTriggerXInspectJobXActionsXSaveFindingsXOutputConfig | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["output_config", b"output_config"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["output_config", b"output_config"]) -> None: ...

global___DataLossPreventionJobTriggerXInspectJobXActionsXSaveFindings = DataLossPreventionJobTriggerXInspectJobXActionsXSaveFindings

@typing_extensions.final
class DataLossPreventionJobTriggerXInspectJobXActions(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SAVE_FINDINGS_FIELD_NUMBER: builtins.int
    @property
    def save_findings(self) -> global___DataLossPreventionJobTriggerXInspectJobXActionsXSaveFindings: ...
    def __init__(
        self,
        *,
        save_findings: global___DataLossPreventionJobTriggerXInspectJobXActionsXSaveFindings | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["save_findings", b"save_findings"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["save_findings", b"save_findings"]) -> None: ...

global___DataLossPreventionJobTriggerXInspectJobXActions = DataLossPreventionJobTriggerXInspectJobXActions

@typing_extensions.final
class DataLossPreventionJobTriggerXInspectJobXStorageConfigXBigQueryOptionsXTableReference(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DATASET_ID_FIELD_NUMBER: builtins.int
    PROJECT_ID_FIELD_NUMBER: builtins.int
    TABLE_ID_FIELD_NUMBER: builtins.int
    dataset_id: builtins.str
    project_id: builtins.str
    table_id: builtins.str
    def __init__(
        self,
        *,
        dataset_id: builtins.str = ...,
        project_id: builtins.str = ...,
        table_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["dataset_id", b"dataset_id", "project_id", b"project_id", "table_id", b"table_id"]) -> None: ...

global___DataLossPreventionJobTriggerXInspectJobXStorageConfigXBigQueryOptionsXTableReference = DataLossPreventionJobTriggerXInspectJobXStorageConfigXBigQueryOptionsXTableReference

@typing_extensions.final
class DataLossPreventionJobTriggerXInspectJobXStorageConfigXBigQueryOptions(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TABLE_REFERENCE_FIELD_NUMBER: builtins.int
    @property
    def table_reference(self) -> global___DataLossPreventionJobTriggerXInspectJobXStorageConfigXBigQueryOptionsXTableReference: ...
    def __init__(
        self,
        *,
        table_reference: global___DataLossPreventionJobTriggerXInspectJobXStorageConfigXBigQueryOptionsXTableReference | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["table_reference", b"table_reference"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["table_reference", b"table_reference"]) -> None: ...

global___DataLossPreventionJobTriggerXInspectJobXStorageConfigXBigQueryOptions = DataLossPreventionJobTriggerXInspectJobXStorageConfigXBigQueryOptions

@typing_extensions.final
class DataLossPreventionJobTriggerXInspectJobXStorageConfigXCloudStorageOptionsXFileSetXRegexFileSet(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BUCKET_NAME_FIELD_NUMBER: builtins.int
    EXCLUDE_REGEX_FIELD_NUMBER: builtins.int
    INCLUDE_REGEX_FIELD_NUMBER: builtins.int
    bucket_name: builtins.str
    @property
    def exclude_regex(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def include_regex(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    def __init__(
        self,
        *,
        bucket_name: builtins.str = ...,
        exclude_regex: collections.abc.Iterable[builtins.str] | None = ...,
        include_regex: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["bucket_name", b"bucket_name", "exclude_regex", b"exclude_regex", "include_regex", b"include_regex"]) -> None: ...

global___DataLossPreventionJobTriggerXInspectJobXStorageConfigXCloudStorageOptionsXFileSetXRegexFileSet = DataLossPreventionJobTriggerXInspectJobXStorageConfigXCloudStorageOptionsXFileSetXRegexFileSet

@typing_extensions.final
class DataLossPreventionJobTriggerXInspectJobXStorageConfigXCloudStorageOptionsXFileSet(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    URL_FIELD_NUMBER: builtins.int
    REGEX_FILE_SET_FIELD_NUMBER: builtins.int
    url: builtins.str
    @property
    def regex_file_set(self) -> global___DataLossPreventionJobTriggerXInspectJobXStorageConfigXCloudStorageOptionsXFileSetXRegexFileSet: ...
    def __init__(
        self,
        *,
        url: builtins.str = ...,
        regex_file_set: global___DataLossPreventionJobTriggerXInspectJobXStorageConfigXCloudStorageOptionsXFileSetXRegexFileSet | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["regex_file_set", b"regex_file_set"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["regex_file_set", b"regex_file_set", "url", b"url"]) -> None: ...

global___DataLossPreventionJobTriggerXInspectJobXStorageConfigXCloudStorageOptionsXFileSet = DataLossPreventionJobTriggerXInspectJobXStorageConfigXCloudStorageOptionsXFileSet

@typing_extensions.final
class DataLossPreventionJobTriggerXInspectJobXStorageConfigXCloudStorageOptions(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BYTES_LIMIT_PER_FILE_FIELD_NUMBER: builtins.int
    BYTES_LIMIT_PER_FILE_PERCENT_FIELD_NUMBER: builtins.int
    FILE_TYPES_FIELD_NUMBER: builtins.int
    FILES_LIMIT_PERCENT_FIELD_NUMBER: builtins.int
    SAMPLE_METHOD_FIELD_NUMBER: builtins.int
    FILE_SET_FIELD_NUMBER: builtins.int
    bytes_limit_per_file: builtins.float
    bytes_limit_per_file_percent: builtins.float
    @property
    def file_types(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    files_limit_percent: builtins.float
    sample_method: builtins.str
    @property
    def file_set(self) -> global___DataLossPreventionJobTriggerXInspectJobXStorageConfigXCloudStorageOptionsXFileSet: ...
    def __init__(
        self,
        *,
        bytes_limit_per_file: builtins.float = ...,
        bytes_limit_per_file_percent: builtins.float = ...,
        file_types: collections.abc.Iterable[builtins.str] | None = ...,
        files_limit_percent: builtins.float = ...,
        sample_method: builtins.str = ...,
        file_set: global___DataLossPreventionJobTriggerXInspectJobXStorageConfigXCloudStorageOptionsXFileSet | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["file_set", b"file_set"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["bytes_limit_per_file", b"bytes_limit_per_file", "bytes_limit_per_file_percent", b"bytes_limit_per_file_percent", "file_set", b"file_set", "file_types", b"file_types", "files_limit_percent", b"files_limit_percent", "sample_method", b"sample_method"]) -> None: ...

global___DataLossPreventionJobTriggerXInspectJobXStorageConfigXCloudStorageOptions = DataLossPreventionJobTriggerXInspectJobXStorageConfigXCloudStorageOptions

@typing_extensions.final
class DataLossPreventionJobTriggerXInspectJobXStorageConfigXDatastoreOptionsXKind(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    name: builtins.str
    def __init__(
        self,
        *,
        name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name"]) -> None: ...

global___DataLossPreventionJobTriggerXInspectJobXStorageConfigXDatastoreOptionsXKind = DataLossPreventionJobTriggerXInspectJobXStorageConfigXDatastoreOptionsXKind

@typing_extensions.final
class DataLossPreventionJobTriggerXInspectJobXStorageConfigXDatastoreOptionsXPartitionId(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAMESPACE_ID_FIELD_NUMBER: builtins.int
    PROJECT_ID_FIELD_NUMBER: builtins.int
    namespace_id: builtins.str
    project_id: builtins.str
    def __init__(
        self,
        *,
        namespace_id: builtins.str = ...,
        project_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["namespace_id", b"namespace_id", "project_id", b"project_id"]) -> None: ...

global___DataLossPreventionJobTriggerXInspectJobXStorageConfigXDatastoreOptionsXPartitionId = DataLossPreventionJobTriggerXInspectJobXStorageConfigXDatastoreOptionsXPartitionId

@typing_extensions.final
class DataLossPreventionJobTriggerXInspectJobXStorageConfigXDatastoreOptions(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    KIND_FIELD_NUMBER: builtins.int
    PARTITION_ID_FIELD_NUMBER: builtins.int
    @property
    def kind(self) -> global___DataLossPreventionJobTriggerXInspectJobXStorageConfigXDatastoreOptionsXKind: ...
    @property
    def partition_id(self) -> global___DataLossPreventionJobTriggerXInspectJobXStorageConfigXDatastoreOptionsXPartitionId: ...
    def __init__(
        self,
        *,
        kind: global___DataLossPreventionJobTriggerXInspectJobXStorageConfigXDatastoreOptionsXKind | None = ...,
        partition_id: global___DataLossPreventionJobTriggerXInspectJobXStorageConfigXDatastoreOptionsXPartitionId | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["kind", b"kind", "partition_id", b"partition_id"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["kind", b"kind", "partition_id", b"partition_id"]) -> None: ...

global___DataLossPreventionJobTriggerXInspectJobXStorageConfigXDatastoreOptions = DataLossPreventionJobTriggerXInspectJobXStorageConfigXDatastoreOptions

@typing_extensions.final
class DataLossPreventionJobTriggerXInspectJobXStorageConfigXTimespanConfigXTimestampField(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    name: builtins.str
    def __init__(
        self,
        *,
        name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name"]) -> None: ...

global___DataLossPreventionJobTriggerXInspectJobXStorageConfigXTimespanConfigXTimestampField = DataLossPreventionJobTriggerXInspectJobXStorageConfigXTimespanConfigXTimestampField

@typing_extensions.final
class DataLossPreventionJobTriggerXInspectJobXStorageConfigXTimespanConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENABLE_AUTO_POPULATION_OF_TIMESPAN_CONFIG_FIELD_NUMBER: builtins.int
    END_TIME_FIELD_NUMBER: builtins.int
    START_TIME_FIELD_NUMBER: builtins.int
    TIMESTAMP_FIELD_FIELD_NUMBER: builtins.int
    enable_auto_population_of_timespan_config: builtins.bool
    end_time: builtins.str
    start_time: builtins.str
    @property
    def timestamp_field(self) -> global___DataLossPreventionJobTriggerXInspectJobXStorageConfigXTimespanConfigXTimestampField: ...
    def __init__(
        self,
        *,
        enable_auto_population_of_timespan_config: builtins.bool = ...,
        end_time: builtins.str = ...,
        start_time: builtins.str = ...,
        timestamp_field: global___DataLossPreventionJobTriggerXInspectJobXStorageConfigXTimespanConfigXTimestampField | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["timestamp_field", b"timestamp_field"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["enable_auto_population_of_timespan_config", b"enable_auto_population_of_timespan_config", "end_time", b"end_time", "start_time", b"start_time", "timestamp_field", b"timestamp_field"]) -> None: ...

global___DataLossPreventionJobTriggerXInspectJobXStorageConfigXTimespanConfig = DataLossPreventionJobTriggerXInspectJobXStorageConfigXTimespanConfig

@typing_extensions.final
class DataLossPreventionJobTriggerXInspectJobXStorageConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BIG_QUERY_OPTIONS_FIELD_NUMBER: builtins.int
    CLOUD_STORAGE_OPTIONS_FIELD_NUMBER: builtins.int
    DATASTORE_OPTIONS_FIELD_NUMBER: builtins.int
    TIMESPAN_CONFIG_FIELD_NUMBER: builtins.int
    @property
    def big_query_options(self) -> global___DataLossPreventionJobTriggerXInspectJobXStorageConfigXBigQueryOptions: ...
    @property
    def cloud_storage_options(self) -> global___DataLossPreventionJobTriggerXInspectJobXStorageConfigXCloudStorageOptions: ...
    @property
    def datastore_options(self) -> global___DataLossPreventionJobTriggerXInspectJobXStorageConfigXDatastoreOptions: ...
    @property
    def timespan_config(self) -> global___DataLossPreventionJobTriggerXInspectJobXStorageConfigXTimespanConfig: ...
    def __init__(
        self,
        *,
        big_query_options: global___DataLossPreventionJobTriggerXInspectJobXStorageConfigXBigQueryOptions | None = ...,
        cloud_storage_options: global___DataLossPreventionJobTriggerXInspectJobXStorageConfigXCloudStorageOptions | None = ...,
        datastore_options: global___DataLossPreventionJobTriggerXInspectJobXStorageConfigXDatastoreOptions | None = ...,
        timespan_config: global___DataLossPreventionJobTriggerXInspectJobXStorageConfigXTimespanConfig | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["big_query_options", b"big_query_options", "cloud_storage_options", b"cloud_storage_options", "datastore_options", b"datastore_options", "timespan_config", b"timespan_config"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["big_query_options", b"big_query_options", "cloud_storage_options", b"cloud_storage_options", "datastore_options", b"datastore_options", "timespan_config", b"timespan_config"]) -> None: ...

global___DataLossPreventionJobTriggerXInspectJobXStorageConfig = DataLossPreventionJobTriggerXInspectJobXStorageConfig

@typing_extensions.final
class DataLossPreventionJobTriggerXInspectJob(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INSPECT_TEMPLATE_NAME_FIELD_NUMBER: builtins.int
    ACTIONS_FIELD_NUMBER: builtins.int
    STORAGE_CONFIG_FIELD_NUMBER: builtins.int
    inspect_template_name: builtins.str
    @property
    def actions(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DataLossPreventionJobTriggerXInspectJobXActions]: ...
    @property
    def storage_config(self) -> global___DataLossPreventionJobTriggerXInspectJobXStorageConfig: ...
    def __init__(
        self,
        *,
        inspect_template_name: builtins.str = ...,
        actions: collections.abc.Iterable[global___DataLossPreventionJobTriggerXInspectJobXActions] | None = ...,
        storage_config: global___DataLossPreventionJobTriggerXInspectJobXStorageConfig | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["storage_config", b"storage_config"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["actions", b"actions", "inspect_template_name", b"inspect_template_name", "storage_config", b"storage_config"]) -> None: ...

global___DataLossPreventionJobTriggerXInspectJob = DataLossPreventionJobTriggerXInspectJob

@typing_extensions.final
class DataLossPreventionJobTriggerXTimeouts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_FIELD_NUMBER: builtins.int
    DELETE_FIELD_NUMBER: builtins.int
    UPDATE_FIELD_NUMBER: builtins.int
    create: builtins.str
    delete: builtins.str
    update: builtins.str
    def __init__(
        self,
        *,
        create: builtins.str = ...,
        delete: builtins.str = ...,
        update: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["create", b"create", "delete", b"delete", "update", b"update"]) -> None: ...

global___DataLossPreventionJobTriggerXTimeouts = DataLossPreventionJobTriggerXTimeouts

@typing_extensions.final
class DataLossPreventionJobTriggerXTriggersXSchedule(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RECURRENCE_PERIOD_DURATION_FIELD_NUMBER: builtins.int
    recurrence_period_duration: builtins.str
    def __init__(
        self,
        *,
        recurrence_period_duration: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["recurrence_period_duration", b"recurrence_period_duration"]) -> None: ...

global___DataLossPreventionJobTriggerXTriggersXSchedule = DataLossPreventionJobTriggerXTriggersXSchedule

@typing_extensions.final
class DataLossPreventionJobTriggerXTriggers(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SCHEDULE_FIELD_NUMBER: builtins.int
    @property
    def schedule(self) -> global___DataLossPreventionJobTriggerXTriggersXSchedule: ...
    def __init__(
        self,
        *,
        schedule: global___DataLossPreventionJobTriggerXTriggersXSchedule | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["schedule", b"schedule"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["schedule", b"schedule"]) -> None: ...

global___DataLossPreventionJobTriggerXTriggers = DataLossPreventionJobTriggerXTriggers

@typing_extensions.final
class DataLossPreventionJobTrigger(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DESCRIPTION_FIELD_NUMBER: builtins.int
    DISPLAY_NAME_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    LAST_RUN_TIME_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    PARENT_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    INSPECT_JOB_FIELD_NUMBER: builtins.int
    TIMEOUTS_FIELD_NUMBER: builtins.int
    TRIGGERS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    description: builtins.str
    display_name: builtins.str
    id: builtins.str
    last_run_time: builtins.str
    name: builtins.str
    parent: builtins.str
    status: builtins.str
    @property
    def inspect_job(self) -> global___DataLossPreventionJobTriggerXInspectJob: ...
    @property
    def timeouts(self) -> global___DataLossPreventionJobTriggerXTimeouts: ...
    @property
    def triggers(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DataLossPreventionJobTriggerXTriggers]: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        description: builtins.str = ...,
        display_name: builtins.str = ...,
        id: builtins.str = ...,
        last_run_time: builtins.str = ...,
        name: builtins.str = ...,
        parent: builtins.str = ...,
        status: builtins.str = ...,
        inspect_job: global___DataLossPreventionJobTriggerXInspectJob | None = ...,
        timeouts: global___DataLossPreventionJobTriggerXTimeouts | None = ...,
        triggers: collections.abc.Iterable[global___DataLossPreventionJobTriggerXTriggers] | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["inspect_job", b"inspect_job", "resource_info", b"resource_info", "timeouts", b"timeouts"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["description", b"description", "display_name", b"display_name", "id", b"id", "inspect_job", b"inspect_job", "last_run_time", b"last_run_time", "name", b"name", "parent", b"parent", "resource_info", b"resource_info", "status", b"status", "timeouts", b"timeouts", "triggers", b"triggers"]) -> None: ...

global___DataLossPreventionJobTrigger = DataLossPreventionJobTrigger

@typing_extensions.final
class DataLossPreventionStoredInfoTypeXDictionaryXCloudStoragePath(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PATH_FIELD_NUMBER: builtins.int
    path: builtins.str
    def __init__(
        self,
        *,
        path: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["path", b"path"]) -> None: ...

global___DataLossPreventionStoredInfoTypeXDictionaryXCloudStoragePath = DataLossPreventionStoredInfoTypeXDictionaryXCloudStoragePath

@typing_extensions.final
class DataLossPreventionStoredInfoTypeXDictionaryXWordList(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    WORDS_FIELD_NUMBER: builtins.int
    @property
    def words(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    def __init__(
        self,
        *,
        words: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["words", b"words"]) -> None: ...

global___DataLossPreventionStoredInfoTypeXDictionaryXWordList = DataLossPreventionStoredInfoTypeXDictionaryXWordList

@typing_extensions.final
class DataLossPreventionStoredInfoTypeXDictionary(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLOUD_STORAGE_PATH_FIELD_NUMBER: builtins.int
    WORD_LIST_FIELD_NUMBER: builtins.int
    @property
    def cloud_storage_path(self) -> global___DataLossPreventionStoredInfoTypeXDictionaryXCloudStoragePath: ...
    @property
    def word_list(self) -> global___DataLossPreventionStoredInfoTypeXDictionaryXWordList: ...
    def __init__(
        self,
        *,
        cloud_storage_path: global___DataLossPreventionStoredInfoTypeXDictionaryXCloudStoragePath | None = ...,
        word_list: global___DataLossPreventionStoredInfoTypeXDictionaryXWordList | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["cloud_storage_path", b"cloud_storage_path", "word_list", b"word_list"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["cloud_storage_path", b"cloud_storage_path", "word_list", b"word_list"]) -> None: ...

global___DataLossPreventionStoredInfoTypeXDictionary = DataLossPreventionStoredInfoTypeXDictionary

@typing_extensions.final
class DataLossPreventionStoredInfoTypeXLargeCustomDictionaryXBigQueryFieldXField(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    name: builtins.str
    def __init__(
        self,
        *,
        name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name"]) -> None: ...

global___DataLossPreventionStoredInfoTypeXLargeCustomDictionaryXBigQueryFieldXField = DataLossPreventionStoredInfoTypeXLargeCustomDictionaryXBigQueryFieldXField

@typing_extensions.final
class DataLossPreventionStoredInfoTypeXLargeCustomDictionaryXBigQueryFieldXTable(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DATASET_ID_FIELD_NUMBER: builtins.int
    PROJECT_ID_FIELD_NUMBER: builtins.int
    TABLE_ID_FIELD_NUMBER: builtins.int
    dataset_id: builtins.str
    project_id: builtins.str
    table_id: builtins.str
    def __init__(
        self,
        *,
        dataset_id: builtins.str = ...,
        project_id: builtins.str = ...,
        table_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["dataset_id", b"dataset_id", "project_id", b"project_id", "table_id", b"table_id"]) -> None: ...

global___DataLossPreventionStoredInfoTypeXLargeCustomDictionaryXBigQueryFieldXTable = DataLossPreventionStoredInfoTypeXLargeCustomDictionaryXBigQueryFieldXTable

@typing_extensions.final
class DataLossPreventionStoredInfoTypeXLargeCustomDictionaryXBigQueryField(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FIELD_FIELD_NUMBER: builtins.int
    TABLE_FIELD_NUMBER: builtins.int
    @property
    def field(self) -> global___DataLossPreventionStoredInfoTypeXLargeCustomDictionaryXBigQueryFieldXField: ...
    @property
    def table(self) -> global___DataLossPreventionStoredInfoTypeXLargeCustomDictionaryXBigQueryFieldXTable: ...
    def __init__(
        self,
        *,
        field: global___DataLossPreventionStoredInfoTypeXLargeCustomDictionaryXBigQueryFieldXField | None = ...,
        table: global___DataLossPreventionStoredInfoTypeXLargeCustomDictionaryXBigQueryFieldXTable | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["field", b"field", "table", b"table"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["field", b"field", "table", b"table"]) -> None: ...

global___DataLossPreventionStoredInfoTypeXLargeCustomDictionaryXBigQueryField = DataLossPreventionStoredInfoTypeXLargeCustomDictionaryXBigQueryField

@typing_extensions.final
class DataLossPreventionStoredInfoTypeXLargeCustomDictionaryXCloudStorageFileSet(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    URL_FIELD_NUMBER: builtins.int
    url: builtins.str
    def __init__(
        self,
        *,
        url: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["url", b"url"]) -> None: ...

global___DataLossPreventionStoredInfoTypeXLargeCustomDictionaryXCloudStorageFileSet = DataLossPreventionStoredInfoTypeXLargeCustomDictionaryXCloudStorageFileSet

@typing_extensions.final
class DataLossPreventionStoredInfoTypeXLargeCustomDictionaryXOutputPath(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PATH_FIELD_NUMBER: builtins.int
    path: builtins.str
    def __init__(
        self,
        *,
        path: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["path", b"path"]) -> None: ...

global___DataLossPreventionStoredInfoTypeXLargeCustomDictionaryXOutputPath = DataLossPreventionStoredInfoTypeXLargeCustomDictionaryXOutputPath

@typing_extensions.final
class DataLossPreventionStoredInfoTypeXLargeCustomDictionary(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BIG_QUERY_FIELD_FIELD_NUMBER: builtins.int
    CLOUD_STORAGE_FILE_SET_FIELD_NUMBER: builtins.int
    OUTPUT_PATH_FIELD_NUMBER: builtins.int
    @property
    def big_query_field(self) -> global___DataLossPreventionStoredInfoTypeXLargeCustomDictionaryXBigQueryField: ...
    @property
    def cloud_storage_file_set(self) -> global___DataLossPreventionStoredInfoTypeXLargeCustomDictionaryXCloudStorageFileSet: ...
    @property
    def output_path(self) -> global___DataLossPreventionStoredInfoTypeXLargeCustomDictionaryXOutputPath: ...
    def __init__(
        self,
        *,
        big_query_field: global___DataLossPreventionStoredInfoTypeXLargeCustomDictionaryXBigQueryField | None = ...,
        cloud_storage_file_set: global___DataLossPreventionStoredInfoTypeXLargeCustomDictionaryXCloudStorageFileSet | None = ...,
        output_path: global___DataLossPreventionStoredInfoTypeXLargeCustomDictionaryXOutputPath | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["big_query_field", b"big_query_field", "cloud_storage_file_set", b"cloud_storage_file_set", "output_path", b"output_path"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["big_query_field", b"big_query_field", "cloud_storage_file_set", b"cloud_storage_file_set", "output_path", b"output_path"]) -> None: ...

global___DataLossPreventionStoredInfoTypeXLargeCustomDictionary = DataLossPreventionStoredInfoTypeXLargeCustomDictionary

@typing_extensions.final
class DataLossPreventionStoredInfoTypeXRegex(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    GROUP_INDEXES_FIELD_NUMBER: builtins.int
    PATTERN_FIELD_NUMBER: builtins.int
    @property
    def group_indexes(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.float]: ...
    pattern: builtins.str
    def __init__(
        self,
        *,
        group_indexes: collections.abc.Iterable[builtins.float] | None = ...,
        pattern: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["group_indexes", b"group_indexes", "pattern", b"pattern"]) -> None: ...

global___DataLossPreventionStoredInfoTypeXRegex = DataLossPreventionStoredInfoTypeXRegex

@typing_extensions.final
class DataLossPreventionStoredInfoTypeXTimeouts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_FIELD_NUMBER: builtins.int
    DELETE_FIELD_NUMBER: builtins.int
    UPDATE_FIELD_NUMBER: builtins.int
    create: builtins.str
    delete: builtins.str
    update: builtins.str
    def __init__(
        self,
        *,
        create: builtins.str = ...,
        delete: builtins.str = ...,
        update: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["create", b"create", "delete", b"delete", "update", b"update"]) -> None: ...

global___DataLossPreventionStoredInfoTypeXTimeouts = DataLossPreventionStoredInfoTypeXTimeouts

@typing_extensions.final
class DataLossPreventionStoredInfoType(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DESCRIPTION_FIELD_NUMBER: builtins.int
    DISPLAY_NAME_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    PARENT_FIELD_NUMBER: builtins.int
    DICTIONARY_FIELD_NUMBER: builtins.int
    LARGE_CUSTOM_DICTIONARY_FIELD_NUMBER: builtins.int
    REGEX_FIELD_NUMBER: builtins.int
    TIMEOUTS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    description: builtins.str
    display_name: builtins.str
    id: builtins.str
    name: builtins.str
    parent: builtins.str
    @property
    def dictionary(self) -> global___DataLossPreventionStoredInfoTypeXDictionary: ...
    @property
    def large_custom_dictionary(self) -> global___DataLossPreventionStoredInfoTypeXLargeCustomDictionary: ...
    @property
    def regex(self) -> global___DataLossPreventionStoredInfoTypeXRegex: ...
    @property
    def timeouts(self) -> global___DataLossPreventionStoredInfoTypeXTimeouts: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        description: builtins.str = ...,
        display_name: builtins.str = ...,
        id: builtins.str = ...,
        name: builtins.str = ...,
        parent: builtins.str = ...,
        dictionary: global___DataLossPreventionStoredInfoTypeXDictionary | None = ...,
        large_custom_dictionary: global___DataLossPreventionStoredInfoTypeXLargeCustomDictionary | None = ...,
        regex: global___DataLossPreventionStoredInfoTypeXRegex | None = ...,
        timeouts: global___DataLossPreventionStoredInfoTypeXTimeouts | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["dictionary", b"dictionary", "large_custom_dictionary", b"large_custom_dictionary", "regex", b"regex", "resource_info", b"resource_info", "timeouts", b"timeouts"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["description", b"description", "dictionary", b"dictionary", "display_name", b"display_name", "id", b"id", "large_custom_dictionary", b"large_custom_dictionary", "name", b"name", "parent", b"parent", "regex", b"regex", "resource_info", b"resource_info", "timeouts", b"timeouts"]) -> None: ...

global___DataLossPreventionStoredInfoType = DataLossPreventionStoredInfoType
